from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_INSTALLMENT_PAYMENT



class V2TradeInstallmentPaymentRequest(object):
    """
    分期支付
    """

    # 请求日期
    req_date = ""
    # 请求流水号
    req_seq_id = ""
    # 商户号
    huifu_id = ""
    # 交易金额
    trans_amt = ""
    # 分期数
    installment_num = ""
    # 商品描述
    goods_desc = ""
    # 安全信息
    risk_check_data = ""
    # 京东白条分期信息trans_type&#x3D;JDBT时，必填jsonObject字符串，京东白条分期相关信息通过该参数集上送
    jdbt_data = ""

    def post(self, extend_infos):
        """
        分期支付

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_date":self.req_date,
            "req_seq_id":self.req_seq_id,
            "huifu_id":self.huifu_id,
            "trans_amt":self.trans_amt,
            "installment_num":self.installment_num,
            "goods_desc":self.goods_desc,
            "risk_check_data":self.risk_check_data,
            "jdbt_data":self.jdbt_data
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_INSTALLMENT_PAYMENT, required_params)



class MerConfig(object):
    """
    商户配置信息
    """
    private_key = ""
    public_key = ""
    product_id = ""
    sys_id = ""
    

    def __init__(self, private_key, public_key, sys_id, product_id):
        """
        商户配置信息初始化
        :param private_key: 商户私钥，发送请求时加签时使用
        :param public_key: 汇付公钥，返回报文时用来验签
        :param sys_id: 系统号
        :param product_id: 产品号
        """
        self.product_id = product_id
        self.private_key = private_key
        self.public_key = public_key
        self.sys_id = sys_id



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_DIRECT_ZFT_REG



class V2MerchantDirectZftRegRequest(object):
    """
    直付通商户入驻
    """

    # 请求流水号
    req_seq_id = ""
    # 请求时间
    req_date = ""
    # 汇付ID
    huifu_id = ""
    # 开发者的应用ID
    app_id = ""
    # 进件的二级商户名称
    name = ""
    # 商家类型
    merchant_type = ""
    # 商户经营类目
    mcc = ""
    # 商户证件类型
    cert_type = ""
    # 商户证件编号
    cert_no = ""
    # 证件名称目前只有个体工商户商户类型要求填入本字段，填写值为个体工商户营业执照上的名称。&lt;font color&#x3D;&quot;green&quot;&gt;示例值：xxxx小卖铺&lt;/font&gt;
    cert_name = ""
    # 法人名称仅个人商户非必填，其他必填。&lt;font color&#x3D;&quot;green&quot;&gt;示例值：张三&lt;/font&gt;
    legal_name = ""
    # 法人证件号码仅个人商户非必填，其他必填。&lt;font color&#x3D;&quot;green&quot;&gt;示例值：3209261975120284333&lt;/font&gt;
    legal_cert_no = ""
    # 客服电话
    service_phone = ""
    # 经营省
    prov_id = ""
    # 经营市
    area_id = ""
    # 经营区
    district_id = ""
    # 经营详细地址
    detail_addr = ""
    # 联系人姓名
    contact_name = ""
    # 商户联系人业务标识
    contact_tag = ""
    # 联系人类型
    contact_type = ""
    # 联系人手机号
    contact_mobile_no = ""
    # 商户结算卡信息jsonArray格式。本业务当前只允许传入一张结算卡。与支付宝账号字段二选一必填
    zft_card_info_list = ""
    # 商户支付宝账号商户支付宝账号，用作结算账号。与银行卡对象字段二选一必填。&lt;br/&gt;本字段要求支付宝账号的名称与商户名称mch_name同名，且是实名认证过的支付宝账户。&lt;font color&#x3D;&quot;green&quot;&gt;示例值：test@huifu.com&lt;/font&gt;
    alipay_logon_id = ""
    # 商户行业资质类型当商户是特殊行业时必填，具体取值[参见表格](https://mif-pub.alipayobjects.com/QualificationType.xlsx)。&lt;font color&#x3D;&quot;green&quot;&gt;示例值：310&lt;/font&gt;
    industry_qualification_type = ""
    # 商户使用服务
    service = ""
    # 商户与服务商的签约时间
    sign_time_with_isv = ""
    # 商户支付宝账户用于协议确认。目前商业场景（除医疗、中小学教育等）下必填。本字段要求上送的支付宝账号的名称与商户名称name同名，且是实名认证支付宝账户。&lt;font color&#x3D;&quot;green&quot;&gt;示例值：test@huifu.com&lt;/font&gt;
    binding_alipay_logon_id = ""
    # 默认结算类型
    default_settle_type = ""
    # 文件列表
    file_list = ""

    def post(self, extend_infos):
        """
        直付通商户入驻

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "app_id":self.app_id,
            "name":self.name,
            "merchant_type":self.merchant_type,
            "mcc":self.mcc,
            "cert_type":self.cert_type,
            "cert_no":self.cert_no,
            "cert_name":self.cert_name,
            "legal_name":self.legal_name,
            "legal_cert_no":self.legal_cert_no,
            "service_phone":self.service_phone,
            "prov_id":self.prov_id,
            "area_id":self.area_id,
            "district_id":self.district_id,
            "detail_addr":self.detail_addr,
            "contact_name":self.contact_name,
            "contact_tag":self.contact_tag,
            "contact_type":self.contact_type,
            "contact_mobile_no":self.contact_mobile_no,
            "zft_card_info_list":self.zft_card_info_list,
            "alipay_logon_id":self.alipay_logon_id,
            "industry_qualification_type":self.industry_qualification_type,
            "service":self.service,
            "sign_time_with_isv":self.sign_time_with_isv,
            "binding_alipay_logon_id":self.binding_alipay_logon_id,
            "default_settle_type":self.default_settle_type,
            "file_list":self.file_list
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_DIRECT_ZFT_REG, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_ACCTPAYMENT_PAY



class V2TradeAcctpaymentPayRequest(object):
    """
    余额支付
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 出款方商户号
    out_huifu_id = ""
    # 支付金额
    ord_amt = ""
    # 分账对象
    acct_split_bunch = ""
    # 安全信息
    risk_check_data = ""
    # 资金类型资金类型。支付渠道为中信E管家时，资金类型必填（[详见说明](https://paas.huifu.com/open/doc/api/#/yuer/api_zxegjzllx)）
    fund_type = ""
    # 手续费承担方标识余额支付手续费承担方标识；商户余额支付扣收规则为接口指定承担方时必填！枚举值：&lt;br/&gt;OUT：出款方；&lt;br/&gt;IN：分账接受方。&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：IN&lt;/font&gt;
    trans_fee_take_flag = ""

    def post(self, extend_infos):
        """
        余额支付

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "out_huifu_id":self.out_huifu_id,
            "ord_amt":self.ord_amt,
            "acct_split_bunch":self.acct_split_bunch,
            "risk_check_data":self.risk_check_data,
            "fund_type":self.fund_type,
            "trans_fee_take_flag":self.trans_fee_take_flag
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_ACCTPAYMENT_PAY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_BASICDATA_MODIFY



class V2MerchantBasicdataModifyRequest(object):
    """
    商户基本信息修改(2022)
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 上级主体ID
    upper_huifu_id = ""
    # 汇付客户Id
    huifu_id = ""

    def post(self, extend_infos):
        """
        商户基本信息修改(2022)

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "upper_huifu_id":self.upper_huifu_id,
            "huifu_id":self.huifu_id
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_BASICDATA_MODIFY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_PAYMENT_DELAYTRANS_CONFIRMREFUNDQUERY



class V2TradePaymentDelaytransConfirmrefundqueryRequest(object):
    """
    交易确认退款查询
    """

    # 商户号
    huifu_id = ""
    # 原交易请求日期
    org_req_date = ""
    # 原交易请求流水号指交易确认请求流水号，org_req_seq_id和org_hf_seq_id二选一；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：2021091708126665002&lt;/font&gt;
    org_req_seq_id = ""
    # 原退款全局流水号 原交易确认退款全局流水号。org_req_seq_id和org_hf_seq_id二选一；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：003500TOP2B211021163242P447ac132fd200000&lt;/font&gt;
    org_hf_seq_id = ""

    def post(self, extend_infos):
        """
        交易确认退款查询

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "huifu_id":self.huifu_id,
            "org_req_date":self.org_req_date,
            "org_req_seq_id":self.org_req_seq_id,
            "org_hf_seq_id":self.org_hf_seq_id
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_PAYMENT_DELAYTRANS_CONFIRMREFUNDQUERY, required_params)



from dg_sdk.core import log_util

from dg_sdk.core.mer_config import MerConfig
from fishbase.fish_logger import set_log_file, set_log_stdout


class DGClient(object):
    connect_timeout = 15  # 网络请求超时时间
    mer_config: MerConfig  # 商户配置信息

    env = "prod"  # 环境标志位

    BASE_URL = 'https://api.huifu.com'  # 生产地址

    BASE_URL_MER_TEST = "https://opps-stbmertest.testpnr.com" #联调地址

    # sdk 版本
    __version__ = '2.0.7'

    @classmethod
    def init_log(cls, console_enable=False, log_level='', log_tag='{dg-sdk}', log_file_path=''):
        """
        初始化日志输出
        :param log_tag:
        :param log_level:
        :param console_enable: 是否在控台输出日志
        :param log_file_path:
        :return:
        """
        if console_enable:
            set_log_stdout()
        if log_file_path:
            set_log_file(log_file_path)
        if log_level:
            log_util.log_level = log_level
            if log_tag:
                log_util.log_tag = log_tag



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_PAYSCORE_PAY_PAYSCOREPAY



class V2TradePayscorePayPayscorepayRequest(object):
    """
    支付分扣款
    """

    # 请求日期
    req_date = ""
    # 请求流水号
    req_seq_id = ""
    # 商户号
    huifu_id = ""
    # 扣款登记创建请求流水号deduct_req_seq_id与deduct_hf_seq_id二选一；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：2022012614120615001&lt;/font&gt;
    deduct_req_seq_id = ""
    # 扣款登记返回的汇付全局流水号deduct_req_seq_id与deduct_hf_seq_id二选一；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：00470topo1A211015160805P090ac132fef00000&lt;/font&gt;
    deduct_hf_seq_id = ""
    # 微信扣款单号
    out_trade_no = ""
    # 商品描述
    goods_desc = ""
    # 安全信息
    risk_check_data = ""

    def post(self, extend_infos):
        """
        支付分扣款

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_date":self.req_date,
            "req_seq_id":self.req_seq_id,
            "huifu_id":self.huifu_id,
            "deduct_req_seq_id":self.deduct_req_seq_id,
            "deduct_hf_seq_id":self.deduct_hf_seq_id,
            "out_trade_no":self.out_trade_no,
            "goods_desc":self.goods_desc,
            "risk_check_data":self.risk_check_data
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_PAYSCORE_PAY_PAYSCOREPAY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_SETTLE_COLLECTION_RULE_ADD



class V2TradeSettleCollectionRuleAddRequest(object):
    """
    新增归集配置
    """

    # 请求日期
    req_date = ""
    # 请求流水号
    req_seq_id = ""
    # 转入方商户号
    in_huifu_id = ""
    # 转出方商户号
    out_huifu_id = ""
    # 签约人手机号协议类型为电子协议时必填，必须为法人手机号。&lt;font color&#x3D;&quot;green&quot;&gt;示例值：13911111111&lt;/font&gt;
    sign_user_mobile_no = ""
    # 协议文件Id协议类型为纸质协议时必填；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：57cc7f00-600a-33ab-b614-6221bbf2e529&lt;/font&gt;
    file_id = ""

    def post(self, extend_infos):
        """
        新增归集配置

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_date":self.req_date,
            "req_seq_id":self.req_seq_id,
            "in_huifu_id":self.in_huifu_id,
            "out_huifu_id":self.out_huifu_id,
            "sign_user_mobile_no":self.sign_user_mobile_no,
            "file_id":self.file_id
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_SETTLE_COLLECTION_RULE_ADD, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_INVOICE_OPEN



class V2InvoiceOpenRequest(object):
    """
    发票开具
    """

    # 请求流水号
    req_seq_id = ""
    # 请求时间
    req_date = ""
    # 渠道号汇付商户号为空时，必传；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：6666000109812124&lt;/font&gt;
    channel_id = ""
    # 发票类型
    ivc_type = ""
    # 开票类型
    open_type = ""
    # 购方单位名称
    buyer_name = ""
    # 含税合计金额(元)
    order_amt = ""
    # 冲红原因open_type&#x3D;1时必填01：开票有误02：销货退回03：服务终止04：销售转让
    red_apply_reason = ""
    # 冲红申请来源open_type&#x3D;1时必填01：销方02：购方
    red_apply_source = ""
    # 原发票代码openType&#x3D;1时必填；参见[发票右上角](https://paas.huifu.com/open/doc/api/#/fp/api_fp_yanglitu.md)；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：144032209110&lt;/font&gt;
    ori_ivc_code = ""
    # 原发票号码openType&#x3D;1时必填；参见[发票右上角](https://paas.huifu.com/open/doc/api/#/fp/api_fp_yanglitu.md)；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：20685767&lt;/font&gt;
    ori_ivc_number = ""
    # 开票商品信息
    goods_infos = ""
    # 开票人信息
    payer_info = ""

    def post(self, extend_infos):
        """
        发票开具

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "channel_id":self.channel_id,
            "ivc_type":self.ivc_type,
            "open_type":self.open_type,
            "buyer_name":self.buyer_name,
            "order_amt":self.order_amt,
            "red_apply_reason":self.red_apply_reason,
            "red_apply_source":self.red_apply_source,
            "ori_ivc_code":self.ori_ivc_code,
            "ori_ivc_number":self.ori_ivc_number,
            "goods_infos":self.goods_infos,
            "payer_info":self.payer_info
        }
        required_params.update(extend_infos)
        return request_post(V2_INVOICE_OPEN, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_INVOICE_MER_REG



class V2InvoiceMerRegRequest(object):
    """
    商户注册
    """

    # 请求流水号
    req_seq_id = ""
    # 请求时间
    req_date = ""
    # 开票方汇付ID
    huifu_id = ""
    # 纳税人识别号
    tax_payer_id = ""
    # 销方名称
    tax_payer_name = ""
    # 公司电话
    tel_no = ""
    # 公司地址
    reg_address = ""
    # 开户银行
    bank_name = ""
    # 开户账户
    account_no = ""
    # 联系人手机号
    contact_phone_no = ""
    # 开票方式
    open_mode = ""
    # 所属省
    prov_id = ""
    # 所属市
    city_id = ""

    def post(self, extend_infos):
        """
        商户注册

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "tax_payer_id":self.tax_payer_id,
            "tax_payer_name":self.tax_payer_name,
            "tel_no":self.tel_no,
            "reg_address":self.reg_address,
            "bank_name":self.bank_name,
            "account_no":self.account_no,
            "contact_phone_no":self.contact_phone_no,
            "open_mode":self.open_mode,
            "prov_id":self.prov_id,
            "city_id":self.city_id
        }
        required_params.update(extend_infos)
        return request_post(V2_INVOICE_MER_REG, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_APPEAL_COMMON_SUBMIT



class V2MerchantAppealCommonSubmitRequest(object):
    """
    提交申诉
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 商户经营模式
    business_pattern = ""
    # 协查单号
    assist_id = ""
    # 申诉单号
    appeal_id = ""
    # 商户类型
    mer_type = ""
    # 申诉人姓名
    appeal_person_name = ""
    # 申诉人身份证号
    appeal_person_cert_no = ""
    # 申诉人联系电话
    appeal_person_phone_no = ""
    # 法人姓名
    legal_name = ""
    # 法人身份证号
    legal_cert_no = ""
    # 法人联系电话
    legal_phone_no = ""
    # 商户主营业务
    main_business = ""
    # 申诉理由
    appeal_desc = ""

    def post(self, extend_infos):
        """
        提交申诉

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "business_pattern":self.business_pattern,
            "assist_id":self.assist_id,
            "appeal_id":self.appeal_id,
            "mer_type":self.mer_type,
            "appeal_person_name":self.appeal_person_name,
            "appeal_person_cert_no":self.appeal_person_cert_no,
            "appeal_person_phone_no":self.appeal_person_phone_no,
            "legal_name":self.legal_name,
            "legal_cert_no":self.legal_cert_no,
            "legal_phone_no":self.legal_phone_no,
            "main_business":self.main_business,
            "appeal_desc":self.appeal_desc
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_APPEAL_COMMON_SUBMIT, required_params)



from dg_sdk.core.api_request import ApiRequest
from dg_sdk.core.api_request_v1 import ApiRequest as ApiRequestV1
from dg_sdk.dg_client import DGClient
from dg_sdk.core.common_util import generate_mer_order_id
import datetime


def __req_url_init(url):
    """
    预处理请求地址，判断是否包含全量地址，还是仅有 path
    :param url: 请求地址
    :return:
    """

    if DGClient.env == "mertest":
        base_url = DGClient.BASE_URL_MER_TEST
    else:
        base_url = DGClient.BASE_URL

    if "http" in url:
        request_url = url
    else:
        request_url = base_url + url

    return request_url


def __req_param_init(request_params, need_seq_id=True):
    """
    预处理请求参数，补全汇付ID 以及 req_seq_id req_date
    :param request_params:
    :return:
    """
    mer_config = DGClient.mer_config

    if mer_config is None:
        raise RuntimeError('SDK 未初始化')

    # if "huifu_id" not in request_params:
    #     request_params['huifu_id'] = mer_config.huifu_id

    if need_seq_id:
        if not request_params.get('req_seq_id'):
            request_params['req_seq_id'] = generate_mer_order_id()

        if not request_params.get('req_date'):
            request_params['req_date'] = datetime.datetime.now().strftime('%Y%m%d')

    return request_params, mer_config


def request_post(url, request_params, files=None, need_seq_id=True, need_sign=True, need_verfy_sign=True):
    """
    网络请求方法
    :param url: 请求地址
    :param request_params: 请求参数
    :param files: 附带文件，可为空
    :param need_seq_id: 是否需要自动生成 req_seq_id 与 req_date
    :param need_sign: 是否需要签名
    :param need_verfy_sign: 是否需要验签
    :return: 网络请求返回内容
    """

    url = __req_url_init(url)
    request_params, mer_config = __req_param_init(request_params, need_seq_id)

    if "v2" in url:

        ApiRequest.build(mer_config.product_id, mer_config.sys_id, mer_config.private_key, mer_config.public_key, url,
                         request_params, DGClient.__version__, need_sign, need_verfy_sign, DGClient.connect_timeout)

        return ApiRequest.post(files)
    if "v3" in url:

        ApiRequest.build(mer_config.product_id, mer_config.sys_id, mer_config.private_key, mer_config.public_key, url,
                         request_params, DGClient.__version__, need_sign, need_verfy_sign, DGClient.connect_timeout)

        return ApiRequest.post(files)
    else:

        ApiRequestV1.build(mer_config.product_id, mer_config.sys_id, mer_config.private_key, mer_config.public_key, url,
                           request_params, DGClient.__version__, DGClient.connect_timeout)
        return ApiRequestV1.post(files)



from dg_sdk.request.v2_trade_acctpayment_acctlog_query_request import V2TradeAcctpaymentAcctlogQueryRequest
from dg_sdk.request.v2_trade_acctpayment_pay_query_request import V2TradeAcctpaymentPayQueryRequest
from dg_sdk.request.v2_trade_acctpayment_refund_request import V2TradeAcctpaymentRefundRequest
from dg_sdk.request.v2_trade_acctpayment_refund_query_request import V2TradeAcctpaymentRefundQueryRequest
from dg_sdk.request.v2_trade_acctpayment_pay_request import V2TradeAcctpaymentPayRequest
from dg_sdk.request.v2_trade_payment_zxe_unknownincome_dispose_request import V2TradePaymentZxeUnknownincomeDisposeRequest
from dg_sdk.request.v2_trade_payment_zxe_unknownincome_disposequery_request import V2TradePaymentZxeUnknownincomeDisposequeryRequest
from dg_sdk.request.v2_trade_payment_zxe_unknownincome_query_request import V2TradePaymentZxeUnknownincomeQueryRequest
from dg_sdk.request.v2_merchant_elec_card_bind_request import V2MerchantElecCardBindRequest
from dg_sdk.request.v2_merchant_elec_card_unbind_request import V2MerchantElecCardUnbindRequest
from dg_sdk.request.v2_merchant_elec_card_default_request import V2MerchantElecCardDefaultRequest
from dg_sdk.request.v2_bank_balance_query_request import V2BankBalanceQueryRequest
from dg_sdk.request.v2_trade_payrelation_apply_request import V2TradePayrelationApplyRequest
from dg_sdk.request.v2_trade_payment_zxe_acctdetail_query_request import V2TradePaymentZxeAcctdetailQueryRequest
from dg_sdk.request.v2_trade_payment_zxe_incash_query_request import V2TradePaymentZxeIncashQueryRequest
from dg_sdk.request.v2_trade_cardbin_query_request import V2TradeCardbinQueryRequest
from dg_sdk.request.v2_trade_settlement_query_request import V2TradeSettlementQueryRequest
from dg_sdk.request.v2_trade_hosting_payment_preorder_h5_request import V2TradeHostingPaymentPreorderH5Request
from dg_sdk.request.v2_trade_hosting_payment_queryorderinfo_request import V2TradeHostingPaymentQueryorderinfoRequest
from dg_sdk.request.v2_trade_hosting_payment_htrefund_request import V2TradeHostingPaymentHtrefundRequest
from dg_sdk.request.v2_trade_hosting_payment_queryrefundinfo_request import V2TradeHostingPaymentQueryrefundinfoRequest
from dg_sdk.request.v2_trade_hosting_payment_preorder_wx_request import V2TradeHostingPaymentPreorderWxRequest
from dg_sdk.request.v2_trade_hosting_payment_preorder_ali_request import V2TradeHostingPaymentPreorderAliRequest
from dg_sdk.request.v2_trade_settlement_surrogate_request import V2TradeSettlementSurrogateRequest
from dg_sdk.request.v2_quickbuckle_withhold_query_request import V2QuickbuckleWithholdQueryRequest
from dg_sdk.request.v2_quickbuckle_withhold_apply_request import V2QuickbuckleWithholdApplyRequest
from dg_sdk.request.v2_quickbuckle_withhold_page_get_request import V2QuickbuckleWithholdPageGetRequest
from dg_sdk.request.v2_trade_onlinepayment_withholdpay_request import V2TradeOnlinepaymentWithholdpayRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_bankmistake_apply_request import V2TradeOnlinepaymentTransferBankmistakeApplyRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_bankmistake_applyquery_request import V2TradeOnlinepaymentTransferBankmistakeApplyqueryRequest
from dg_sdk.request.v2_largeamt_bindcard_bind_request import V2LargeamtBindcardBindRequest
from dg_sdk.request.v2_largeamt_bindcard_query_request import V2LargeamtBindcardQueryRequest
from dg_sdk.request.v2_largeamt_bindcard_unbind_request import V2LargeamtBindcardUnbindRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_bankblotter_query_request import V2TradeOnlinepaymentTransferBankblotterQueryRequest
from dg_sdk.request.v2_merchant_busi_efpconfig_request import V2MerchantBusiEfpconfigRequest
from dg_sdk.request.v2_merchant_busi_efpdetail_request import V2MerchantBusiEfpdetailRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_account_request import V2TradeOnlinepaymentTransferAccountRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_account_close_request import V2TradeOnlinepaymentTransferAccountCloseRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_remittanceorder_request import V2TradeOnlinepaymentTransferRemittanceorderRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_remittance_request import V2TradeOnlinepaymentTransferRemittanceRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_account_query_request import V2TradeOnlinepaymentTransferAccountQueryRequest
from dg_sdk.request.v2_trade_settlement_enchashment_dmamt_query_request import V2TradeSettlementEnchashmentDmamtQueryRequest
from dg_sdk.request.v2_trade_payment_getelectronicreceipt_request import V2TradePaymentGetelectronicreceiptRequest
from dg_sdk.request.v2_trade_electron_receipts_customentrances_create_request import V2TradeElectronReceiptsCustomentrancesCreateRequest
from dg_sdk.request.v2_trade_electron_receipts_customentrances_query_request import V2TradeElectronReceiptsCustomentrancesQueryRequest
from dg_sdk.request.v2_trade_electron_receipts_upload_request import V2TradeElectronReceiptsUploadRequest
from dg_sdk.request.v2_trade_electron_receipts_picture_upload_request import V2TradeElectronReceiptsPictureUploadRequest
from dg_sdk.request.v2_trade_electron_receipts_jumpinfo_request import V2TradeElectronReceiptsJumpinfoRequest
from dg_sdk.request.v2_invoice_mer_authqrcode_query_request import V2InvoiceMerAuthqrcodeQueryRequest
from dg_sdk.request.v2_invoice_mer_authqrcode_grant_request import V2InvoiceMerAuthqrcodeGrantRequest
from dg_sdk.request.v2_invoice_open_request import V2InvoiceOpenRequest
from dg_sdk.request.v2_invoice_queryapply_request import V2InvoiceQueryapplyRequest
from dg_sdk.request.v2_invoice_clerk_reg_request import V2InvoiceClerkRegRequest
from dg_sdk.request.v2_invoice_clerk_logon_request import V2InvoiceClerkLogonRequest
from dg_sdk.request.v2_invoice_mer_verifycode_upload_request import V2InvoiceMerVerifycodeUploadRequest
from dg_sdk.request.v2_invoice_mer_reg_request import V2InvoiceMerRegRequest
from dg_sdk.request.v2_invoice_mer_query_request import V2InvoiceMerQueryRequest
from dg_sdk.request.v2_invoice_mer_modify_request import V2InvoiceMerModifyRequest
from dg_sdk.request.v2_invoice_mer_status_query_request import V2InvoiceMerStatusQueryRequest
from dg_sdk.request.v2_invoice_permission_grant_request import V2InvoicePermissionGrantRequest
from dg_sdk.request.v2_invoice_permission_query_request import V2InvoicePermissionQueryRequest
from dg_sdk.request.v2_invoice_selfscanopen_request import V2InvoiceSelfscanopenRequest
from dg_sdk.request.v2_trade_trans_split_query_request import V2TradeTransSplitQueryRequest
from dg_sdk.request.v2_wallet_trade_recharge_card_request import V2WalletTradeRechargeCardRequest
from dg_sdk.request.v2_wallet_trade_query_request import V2WalletTradeQueryRequest
from dg_sdk.request.v2_wallet_password_reset_request import V2WalletPasswordResetRequest
from dg_sdk.request.v2_wallet_password_modify_request import V2WalletPasswordModifyRequest
from dg_sdk.request.v2_wallet_trade_order_close_request import V2WalletTradeOrderCloseRequest
from dg_sdk.request.v2_wallet_create_request import V2WalletCreateRequest
from dg_sdk.request.v2_wallet_query_request import V2WalletQueryRequest
from dg_sdk.request.v2_wallet_mobile_verify_request import V2WalletMobileVerifyRequest
from dg_sdk.request.v2_wallet_trade_withdrawal_request import V2WalletTradeWithdrawalRequest
from dg_sdk.request.v2_wallet_card_add_request import V2WalletCardAddRequest
from dg_sdk.request.v2_wallet_card_query_request import V2WalletCardQueryRequest
from dg_sdk.request.v2_wallet_trade_recharge_transfer_request import V2WalletTradeRechargeTransferRequest
from dg_sdk.request.v2_wallet_trade_pay_refund_request import V2WalletTradePayRefundRequest
from dg_sdk.request.v2_wallet_trade_pay_refund_query_request import V2WalletTradePayRefundQueryRequest
from dg_sdk.request.v2_wallet_trade_pay_balance_request import V2WalletTradePayBalanceRequest
from dg_sdk.request.v2_wallet_trade_transfer_request import V2WalletTradeTransferRequest
from dg_sdk.request.v2_pcredit_solution_create_request import V2PcreditSolutionCreateRequest
from dg_sdk.request.v2_trade_installment_payment_request import V2TradeInstallmentPaymentRequest
from dg_sdk.request.v2_pcredit_order_query_request import V2PcreditOrderQueryRequest
from dg_sdk.request.v2_pcredit_statue_modify_request import V2PcreditStatueModifyRequest
from dg_sdk.request.v2_pcredit_solution_modify_request import V2PcreditSolutionModifyRequest
from dg_sdk.request.v2_pcredit_solution_query_request import V2PcreditSolutionQueryRequest
from dg_sdk.request.v2_pcredit_certificate_config_request import V2PcreditCertificateConfigRequest
from dg_sdk.request.v2_trade_bankinstallmentinfo_query_request import V2TradeBankinstallmentinfoQueryRequest
from dg_sdk.request.v2_pcredit_fee_config_request import V2PcreditFeeConfigRequest
from dg_sdk.request.v2_pcredit_fee_detail_request import V2PcreditFeeDetailRequest
from dg_sdk.request.v2_hyc_personsign_create_request import V2HycPersonsignCreateRequest
from dg_sdk.request.v2_hyc_contract_query_request import V2HycContractQueryRequest
from dg_sdk.request.v2_hyc_invcategory_query_request import V2HycInvcategoryQueryRequest
from dg_sdk.request.v2_hyc_invinfo_query_request import V2HycInvinfoQueryRequest
from dg_sdk.request.v2_trade_lgwx_surrogate_request import V2TradeLgwxSurrogateRequest
from dg_sdk.request.v2_trade_lgwx_surrogate_query_request import V2TradeLgwxSurrogateQueryRequest
from dg_sdk.request.v2_hyc_mersign_query_request import V2HycMersignQueryRequest
from dg_sdk.request.v2_hyc_invoice_apply_request import V2HycInvoiceApplyRequest
from dg_sdk.request.v2_hyc_tax_query_request import V2HycTaxQueryRequest
from dg_sdk.request.v2_hyc_tax_download_request import V2HycTaxDownloadRequest
from dg_sdk.request.v2_trade_payment_micropay_request import V2TradePaymentMicropayRequest
from dg_sdk.request.v2_trade_payment_jspay_request import V2TradePaymentJspayRequest
from dg_sdk.request.v2_merchant_basicdata_settlement_query_request import V2MerchantBasicdataSettlementQueryRequest
from dg_sdk.request.v2_trade_payment_scanpay_closequery_request import V2TradePaymentScanpayClosequeryRequest
from dg_sdk.request.v2_trade_settle_collection_detail_query_request import V2TradeSettleCollectionDetailQueryRequest
from dg_sdk.request.v2_trade_settle_collection_rule_query_request import V2TradeSettleCollectionRuleQueryRequest
from dg_sdk.request.v2_trade_check_replay_request import V2TradeCheckReplayRequest
from dg_sdk.request.v2_trade_check_filequery_request import V2TradeCheckFilequeryRequest
from dg_sdk.request.v2_merchant_busi_bill_config_request import V2MerchantBusiBillConfigRequest
from dg_sdk.request.v2_merchant_busi_bill_query_request import V2MerchantBusiBillQueryRequest
from dg_sdk.request.v2_trade_settle_collection_rule_modify_request import V2TradeSettleCollectionRuleModifyRequest
from dg_sdk.request.v2_trade_settle_collection_rule_add_request import V2TradeSettleCollectionRuleAddRequest
from dg_sdk.request.v2_trade_acctpayment_balance_query_request import V2TradeAcctpaymentBalanceQueryRequest
from dg_sdk.request.v2_trade_payment_delaytrans_confirm_request import V2TradePaymentDelaytransConfirmRequest
from dg_sdk.request.v2_trade_payment_delaytrans_confirmquery_request import V2TradePaymentDelaytransConfirmqueryRequest
from dg_sdk.request.v2_trade_payment_delaytrans_confirmrefund_request import V2TradePaymentDelaytransConfirmrefundRequest
from dg_sdk.request.v2_trade_payment_delaytrans_confirmrefundquery_request import V2TradePaymentDelaytransConfirmrefundqueryRequest
from dg_sdk.request.v2_quickbuckle_query_request import V2QuickbuckleQueryRequest
from dg_sdk.request.v3_quickbuckle_confirm_request import V3QuickbuckleConfirmRequest
from dg_sdk.request.v3_quickbuckle_apply_request import V3QuickbuckleApplyRequest
from dg_sdk.request.v2_trade_onlinepayment_quickpay_smscheck_request import V2TradeOnlinepaymentQuickpaySmscheckRequest
from dg_sdk.request.v2_quickbuckle_bind_cardinfo_query_request import V2QuickbuckleBindCardinfoQueryRequest
from dg_sdk.request.v2_quickbuckle_unbind_request import V2QuickbuckleUnbindRequest
from dg_sdk.request.v2_trade_onlinepayment_quickpay_frontpay_request import V2TradeOnlinepaymentQuickpayFrontpayRequest
from dg_sdk.request.v3_trade_onlinepayment_quickpay_smssend_request import V3TradeOnlinepaymentQuickpaySmssendRequest
from dg_sdk.request.v3_trade_onlinepayment_quickpay_pay_request import V3TradeOnlinepaymentQuickpayPayRequest
from dg_sdk.request.v2_trade_batchtranslog_query_request import V2TradeBatchtranslogQueryRequest
from dg_sdk.request.v2_trade_transstat_query_request import V2TradeTransstatQueryRequest
from dg_sdk.request.v2_trade_payment_scanpay_query_request import V2TradePaymentScanpayQueryRequest
from dg_sdk.request.v2_trade_payment_scanpay_close_request import V2TradePaymentScanpayCloseRequest
from dg_sdk.request.v2_trade_payment_scanpay_refund_request import V2TradePaymentScanpayRefundRequest
from dg_sdk.request.v2_trade_payment_scanpay_refundquery_request import V2TradePaymentScanpayRefundqueryRequest
from dg_sdk.request.v2_trade_payment_usermark2_query_request import V2TradePaymentUsermark2QueryRequest
from dg_sdk.request.v2_trade_settlement_enchashment_request import V2TradeSettlementEnchashmentRequest
from dg_sdk.request.v2_merchant_appeal_log_query_request import V2MerchantAppealLogQueryRequest
from dg_sdk.request.v2_merchant_appeal_relatedclue_query_request import V2MerchantAppealRelatedclueQueryRequest
from dg_sdk.request.v2_merchant_appeal_custinfo_query_request import V2MerchantAppealCustinfoQueryRequest
from dg_sdk.request.v2_merchant_appeal_list_query_request import V2MerchantAppealListQueryRequest
from dg_sdk.request.v2_merchant_appeal_fileurl_query_request import V2MerchantAppealFileurlQueryRequest
from dg_sdk.request.v2_merchant_appeal_common_submit_request import V2MerchantAppealCommonSubmitRequest
from dg_sdk.request.v2_merchant_appeal_detail_query_request import V2MerchantAppealDetailQueryRequest
from dg_sdk.request.v2_merchant_busi_modify_busistatus_request import V2MerchantBusiModifyBusistatusRequest
from dg_sdk.request.v2_merchant_complaint_complete_request import V2MerchantComplaintCompleteRequest
from dg_sdk.request.v2_merchant_complaint_reply_request import V2MerchantComplaintReplyRequest
from dg_sdk.request.v2_merchant_complaint_update_refundprogress_request import V2MerchantComplaintUpdateRefundprogressRequest
from dg_sdk.request.v2_merchant_complaint_download_picture_request import V2MerchantComplaintDownloadPictureRequest
from dg_sdk.request.v2_merchant_complaint_list_info_query_request import V2MerchantComplaintListInfoQueryRequest
from dg_sdk.request.v2_merchant_complaint_history_query_request import V2MerchantComplaintHistoryQueryRequest
from dg_sdk.request.v2_merchant_complaint_ali_riskinfo_query_request import V2MerchantComplaintAliRiskinfoQueryRequest
from dg_sdk.request.v2_merchant_complaint_request_certificates_request import V2MerchantComplaintRequestCertificatesRequest
from dg_sdk.request.v2_merchant_complaint_query_status_request import V2MerchantComplaintQueryStatusRequest
from dg_sdk.request.v2_merchant_complaint_submit_certificates_request import V2MerchantComplaintSubmitCertificatesRequest
from dg_sdk.request.v2_merchant_busi_at_modify_request import V2MerchantBusiAtModifyRequest
from dg_sdk.request.v2_merchant_busi_mercode_query_request import V2MerchantBusiMercodeQueryRequest
from dg_sdk.request.v2_merchant_basicdata_indv_request import V2MerchantBasicdataIndvRequest
from dg_sdk.request.v2_merchant_basicdata_ent_request import V2MerchantBasicdataEntRequest
from dg_sdk.request.v2_merchant_basicdata_sms_send_request import V2MerchantBasicdataSmsSendRequest
from dg_sdk.request.v2_merchant_activity_add_request import V2MerchantActivityAddRequest
from dg_sdk.request.v2_merchant_activity_query_request import V2MerchantActivityQueryRequest
from dg_sdk.request.v2_merchant_basicdata_modify_request import V2MerchantBasicdataModifyRequest
from dg_sdk.request.v2_supplementary_picture_request import V2SupplementaryPictureRequest
from dg_sdk.request.v2_merchant_url_forward_request import V2MerchantUrlForwardRequest
from dg_sdk.request.v2_merchant_busi_status_query_request import V2MerchantBusiStatusQueryRequest
from dg_sdk.request.v2_merchant_basicdata_query_request import V2MerchantBasicdataQueryRequest
from dg_sdk.request.v2_merchant_busi_open_request import V2MerchantBusiOpenRequest
from dg_sdk.request.v2_merchant_busi_modify_request import V2MerchantBusiModifyRequest
from dg_sdk.request.v2_merchant_busi_head_config_request import V2MerchantBusiHeadConfigRequest
from dg_sdk.request.v2_merchant_basicdata_status_query_request import V2MerchantBasicdataStatusQueryRequest
from dg_sdk.request.v2_merchant_busi_config_request import V2MerchantBusiConfigRequest
from dg_sdk.request.v2_merchant_busi_config_query_request import V2MerchantBusiConfigQueryRequest
from dg_sdk.request.v2_merchant_busi_realname_request import V2MerchantBusiRealnameRequest
from dg_sdk.request.v2_merchant_busi_realname_query_request import V2MerchantBusiRealnameQueryRequest
from dg_sdk.request.v2_quickbuckle_bank_query_request import V2QuickbuckleBankQueryRequest
from dg_sdk.request.v2_merchant_busi_ali_realname_query_request import V2MerchantBusiAliRealnameQueryRequest
from dg_sdk.request.v2_merchant_busi_ali_realname_apply_request import V2MerchantBusiAliRealnameApplyRequest
from dg_sdk.request.v2_trade_feecalc_request import V2TradeFeecalcRequest
from dg_sdk.request.v2_trade_onlinepayment_unionpay_request import V2TradeOnlinepaymentUnionpayRequest
from dg_sdk.request.v2_trade_wxusermark_query_request import V2TradeWxusermarkQueryRequest
from dg_sdk.request.v2_trade_payscore_serviceorder_create_request import V2TradePayscoreServiceorderCreateRequest
from dg_sdk.request.v2_trade_payscore_serviceorder_query_request import V2TradePayscoreServiceorderQueryRequest
from dg_sdk.request.v2_trade_payscore_deduct_query_request import V2TradePayscoreDeductQueryRequest
from dg_sdk.request.v2_trade_payscore_deduct_regitster_request import V2TradePayscoreDeductRegitsterRequest
from dg_sdk.request.v2_trade_payscore_serviceorder_cancel_request import V2TradePayscoreServiceorderCancelRequest
from dg_sdk.request.v2_trade_payscore_serviceorder_complete_request import V2TradePayscoreServiceorderCompleteRequest
from dg_sdk.request.v2_trade_payscore_pay_payscorepay_request import V2TradePayscorePayPayscorepayRequest
from dg_sdk.request.v2_merchant_direct_wechat_settlementinfo_query_request import V2MerchantDirectWechatSettlementinfoQueryRequest
from dg_sdk.request.v2_merchant_direct_wechat_query_request import V2MerchantDirectWechatQueryRequest
from dg_sdk.request.v2_merchant_direct_wechat_subscribe_config_request import V2MerchantDirectWechatSubscribeConfigRequest
from dg_sdk.request.v2_merchant_direct_wechat_subscribe_query_request import V2MerchantDirectWechatSubscribeQueryRequest
from dg_sdk.request.v2_merchant_direct_wechat_sign_request import V2MerchantDirectWechatSignRequest
from dg_sdk.request.v2_merchant_direct_wechat_settlementinfo_modify_request import V2MerchantDirectWechatSettlementinfoModifyRequest
from dg_sdk.request.v2_merchant_direct_certinfo_add_request import V2MerchantDirectCertinfoAddRequest
from dg_sdk.request.v2_trade_onlinepayment_bankpay_payerquery_request import V2TradeOnlinepaymentBankpayPayerqueryRequest
from dg_sdk.request.v2_trade_onlinepayment_wappay_request import V2TradeOnlinepaymentWappayRequest
from dg_sdk.request.v2_trade_onlinepayment_bankpay_banklist_request import V2TradeOnlinepaymentBankpayBanklistRequest
from dg_sdk.request.v2_trade_onlinepayment_banking_frontpay_request import V2TradeOnlinepaymentBankingFrontpayRequest
from dg_sdk.request.v2_trade_onlinepayment_query_request import V2TradeOnlinepaymentQueryRequest
from dg_sdk.request.v2_trade_onlinepayment_refund_request import V2TradeOnlinepaymentRefundRequest
from dg_sdk.request.v2_trade_onlinepayment_refund_query_request import V2TradeOnlinepaymentRefundQueryRequest
from dg_sdk.request.v2_user_basicdata_indv_modify_request import V2UserBasicdataIndvModifyRequest
from dg_sdk.request.v2_user_basicdata_indv_request import V2UserBasicdataIndvRequest
from dg_sdk.request.v2_user_basicdata_ent_modify_request import V2UserBasicdataEntModifyRequest
from dg_sdk.request.v2_user_basicdata_ent_request import V2UserBasicdataEntRequest
from dg_sdk.request.v2_user_list_query_request import V2UserListQueryRequest
from dg_sdk.request.v2_user_apply_query_request import V2UserApplyQueryRequest
from dg_sdk.request.v2_user_basicdata_query_request import V2UserBasicdataQueryRequest
from dg_sdk.request.v2_user_busi_open_request import V2UserBusiOpenRequest
from dg_sdk.request.v2_user_busi_modify_request import V2UserBusiModifyRequest
from dg_sdk.request.v2_quickbuckle_onekey_cardbind_request import V2QuickbuckleOnekeyCardbindRequest
from dg_sdk.request.v2_trade_preauth_request import V2TradePreauthRequest
from dg_sdk.request.v2_trade_payment_preauthcancel_refund_request import V2TradePaymentPreauthcancelRefundRequest
from dg_sdk.request.v2_trade_preauthpay_request import V2TradePreauthpayRequest
from dg_sdk.request.v2_trade_payment_preauthpaycancel_refund_request import V2TradePaymentPreauthpaycancelRefundRequest
from dg_sdk.request.v2_terminaldevice_deviceinfo_query_request import V2TerminaldeviceDeviceinfoQueryRequest
from dg_sdk.request.v2_terminaldevice_deviceinfo_add_request import V2TerminaldeviceDeviceinfoAddRequest
from dg_sdk.request.v2_terminaldevice_deviceinfo_cancel_request import V2TerminaldeviceDeviceinfoCancelRequest
from dg_sdk.request.v2_terminaldevice_manage_bind_request import V2TerminaldeviceManageBindRequest
from dg_sdk.request.v2_terminaldevice_manage_unbind_request import V2TerminaldeviceManageUnbindRequest
from dg_sdk.request.v2_terminaldevice_manage_query_request import V2TerminaldeviceManageQueryRequest
from dg_sdk.request.v2_bill_ent_create_request import V2BillEntCreateRequest
from dg_sdk.request.v2_bill_ent_payer_query_request import V2BillEntPayerQueryRequest
from dg_sdk.request.v2_bill_ent_query_request import V2BillEntQueryRequest
from dg_sdk.request.v2_bill_ent_refund_request import V2BillEntRefundRequest
from dg_sdk.request.v2_bill_ent_refund_query_request import V2BillEntRefundQueryRequest
from dg_sdk.request.v2_bill_ent_changestat_request import V2BillEntChangestatRequest
from dg_sdk.request.v2_bill_ent_payer_delete_request import V2BillEntPayerDeleteRequest
from dg_sdk.request.v2_bill_ent_payer_update_request import V2BillEntPayerUpdateRequest
from dg_sdk.request.v2_bill_ent_payer_create_request import V2BillEntPayerCreateRequest
from dg_sdk.request.v2_merchant_direct_zft_receiver_config_request import V2MerchantDirectZftReceiverConfigRequest
from dg_sdk.request.v2_merchant_direct_zft_receiver_query_request import V2MerchantDirectZftReceiverQueryRequest
from dg_sdk.request.v2_merchant_direct_zft_reg_request import V2MerchantDirectZftRegRequest
from dg_sdk.request.v2_merchant_direct_alipay_applyorderstatus_query_request import V2MerchantDirectAlipayApplyorderstatusQueryRequest
from dg_sdk.request.v2_merchant_direct_alipay_appauthtoken_exchange_request import V2MerchantDirectAlipayAppauthtokenExchangeRequest
from dg_sdk.request.v2_merchant_direct_alipay_facetofacesign_apply_request import V2MerchantDirectAlipayFacetofacesignApplyRequest
from dg_sdk.request.v2_trade_payafteruse_installment_create_request import V2TradePayafteruseInstallmentCreateRequest
from dg_sdk.request.v2_trade_payafteruse_installment_refund_request import V2TradePayafteruseInstallmentRefundRequest
from dg_sdk.request.v2_trade_payafteruse_installment_refundquery_request import V2TradePayafteruseInstallmentRefundqueryRequest
from dg_sdk.request.v2_trade_payafteruse_installment_pay_request import V2TradePayafteruseInstallmentPayRequest
from dg_sdk.request.v2_trade_payafteruse_installment_query_request import V2TradePayafteruseInstallmentQueryRequest
from dg_sdk.request.v2_trade_payafteruse_creditbizorder_create_request import V2TradePayafteruseCreditbizorderCreateRequest
from dg_sdk.request.v2_trade_payafteruse_creditbizorder_query_request import V2TradePayafteruseCreditbizorderQueryRequest
from dg_sdk.request.v2_trade_payafteruse_creditbizorder_close_request import V2TradePayafteruseCreditbizorderCloseRequest
from dg_sdk.request.v2_merchant_settle_modify_request import V2MerchantSettleModifyRequest
from dg_sdk.request.v2_merchant_settle_config_request import V2MerchantSettleConfigRequest
from dg_sdk.request.v2_trade_cloudmis_device_information_mis_request import V2TradeCloudmisDeviceInformationMisRequest
from dg_sdk.request.v2_trade_cloudmis_order_detail_request import V2TradeCloudmisOrderDetailRequest



import random
import time
import datetime
import functools
from fishbase import logger as fishbase_logger


def generate_mer_order_id():
    """
    生成请求order_no，根据时间戳+6位随机数
    :return:
    """
    timestamp = str(datetime.datetime.now().strftime('%Y%m%d%H%M%S'))
    return "" + timestamp + str(random.randint(100000, 9999999))


def generate_req_date():
    """
    获取当前日期，格式%Y%m%d
    :return: 日期
    """
    return datetime.datetime.now().strftime('%Y%m%d')


def time_func(func):
    """
    计算方法耗时
    """

    @functools.wraps(func)
    def wrapper(*args, **kwargs):
        start = time.time()
        r = func(*args, **kwargs)
        end = time.time()
        data = 'func.__name__={}, func.inputs_args={}, \n' \
               'func.inputs_kwargs={}, \n' \
               'elapsed={} \n'.format(func.__name__, args, kwargs, end - start)
        fishbase_logger.info(data)
        return r

    return wrapper



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_APPEAL_LIST_QUERY



class V2MerchantAppealListQueryRequest(object):
    """
    申诉单列表查询
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 分页条数
    page_size = ""
    # 申诉创建开始日期
    begin_date = ""
    # 申诉创建结束日期
    end_date = ""

    def post(self, extend_infos):
        """
        申诉单列表查询

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "page_size":self.page_size,
            "begin_date":self.begin_date,
            "end_date":self.end_date
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_APPEAL_LIST_QUERY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_PCREDIT_SOLUTION_CREATE



class V2PcreditSolutionCreateRequest(object):
    """
    创建花呗分期方案
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 汇付客户Id
    huifu_id = ""
    # 花呗分期商家贴息活动名称
    activity_name = ""
    # 活动开始时间
    start_time = ""
    # 活动结束时间
    end_time = ""
    # 免息金额下限(元)
    min_money_limit = ""
    # 免息金额上限(元)
    max_money_limit = ""
    # 花呗分期贴息预算金额
    amount_budget = ""
    # 花呗分期数集合
    install_num_str_list = ""
    # 预算提醒金额(元)
    budget_warning_money = ""
    # 预算提醒邮件列表
    budget_warning_mail_list = ""
    # 预算提醒手机号列表
    budget_warning_mobile_no_list = ""
    # 子门店信息集合
    sub_shop_info_list = ""

    def post(self, extend_infos):
        """
        创建花呗分期方案

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "activity_name":self.activity_name,
            "start_time":self.start_time,
            "end_time":self.end_time,
            "min_money_limit":self.min_money_limit,
            "max_money_limit":self.max_money_limit,
            "amount_budget":self.amount_budget,
            "install_num_str_list":self.install_num_str_list,
            "budget_warning_money":self.budget_warning_money,
            "budget_warning_mail_list":self.budget_warning_mail_list,
            "budget_warning_mobile_no_list":self.budget_warning_mobile_no_list,
            "sub_shop_info_list":self.sub_shop_info_list
        }
        required_params.update(extend_infos)
        return request_post(V2_PCREDIT_SOLUTION_CREATE, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_ONLINEPAYMENT_TRANSFER_BANKMISTAKE_APPLYQUERY



class V2TradeOnlinepaymentTransferBankmistakeApplyqueryRequest(object):
    """
    银行大额支付差错申请查询
    """

    # 商户号
    huifu_id = ""
    # 原请求日期
    org_req_date = ""
    # 原请求流水号
    org_req_seq_id = ""
    # 订单类型
    order_type = ""

    def post(self, extend_infos):
        """
        银行大额支付差错申请查询

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "huifu_id":self.huifu_id,
            "org_req_date":self.org_req_date,
            "org_req_seq_id":self.org_req_seq_id,
            "order_type":self.order_type
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_ONLINEPAYMENT_TRANSFER_BANKMISTAKE_APPLYQUERY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V3_TRADE_ONLINEPAYMENT_QUICKPAY_SMSSEND



class V3TradeOnlinepaymentQuickpaySmssendRequest(object):
    """
    快捷短信发送
    """

    # 请求日期
    req_date = ""
    # 请求流水号
    req_seq_id = ""
    # 商户号
    huifu_id = ""
    # 用户客户号
    user_huifu_id = ""
    # 绑卡id
    card_bind_id = ""
    # 订单金额
    trans_amt = ""
    # 异步通知地址
    notify_url = ""
    # 网联数据
    nucc_data = ""
    # 设备数据
    terminal_device_data = ""
    # 安全信息
    risk_check_data = ""

    def post(self, extend_infos):
        """
        快捷短信发送

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_date":self.req_date,
            "req_seq_id":self.req_seq_id,
            "huifu_id":self.huifu_id,
            "user_huifu_id":self.user_huifu_id,
            "card_bind_id":self.card_bind_id,
            "trans_amt":self.trans_amt,
            "notify_url":self.notify_url,
            "nucc_data":self.nucc_data,
            "terminal_device_data":self.terminal_device_data,
            "risk_check_data":self.risk_check_data
        }
        required_params.update(extend_infos)
        return request_post(V3_TRADE_ONLINEPAYMENT_QUICKPAY_SMSSEND, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_CLOUDMIS_ORDER_DETAIL



class V2TradeCloudmisOrderDetailRequest(object):
    """
    云MIS订单详情查询接口
    """

    # 原MIS请求商户号
    org_huifu_id = ""
    # 原MIS请求终端号
    org_device_id = ""
    # 原MIS请求日期
    org_req_date = ""

    def post(self, extend_infos):
        """
        云MIS订单详情查询接口

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "org_huifu_id":self.org_huifu_id,
            "org_device_id":self.org_device_id,
            "org_req_date":self.org_req_date
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_CLOUDMIS_ORDER_DETAIL, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_HYC_INVINFO_QUERY



class V2HycInvinfoQueryRequest(object):
    """
    开票信息查询
    """

    # 系统号
    sys_id = ""
    # 产品号
    product_id = ""
    # 加签结果
    sign = ""
    # 数据
    data = ""

    def post(self, extend_infos):
        """
        开票信息查询

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "sys_id":self.sys_id,
            "product_id":self.product_id,
            "sign":self.sign,
            "data":self.data
        }
        required_params.update(extend_infos)
        return request_post(V2_HYC_INVINFO_QUERY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_USER_BASICDATA_ENT_MODIFY



class V2UserBasicdataEntModifyRequest(object):
    """
    企业用户基本信息修改
    """

    # 请求日期
    req_date = ""
    # 请求流水号
    req_seq_id = ""
    # 汇付客户Id
    huifu_id = ""

    def post(self, extend_infos):
        """
        企业用户基本信息修改

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_date":self.req_date,
            "req_seq_id":self.req_seq_id,
            "huifu_id":self.huifu_id
        }
        required_params.update(extend_infos)
        return request_post(V2_USER_BASICDATA_ENT_MODIFY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_DIRECT_ALIPAY_APPAUTHTOKEN_EXCHANGE



class V2MerchantDirectAlipayAppauthtokenExchangeRequest(object):
    """
    支付宝直连-换取应用授权令牌
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 汇付ID
    huifu_id = ""
    # 开发者的应用ID
    app_id = ""
    # 操作类型
    oper_type = ""
    # 授权码授权码，操作类型为0-换取令牌时必填，其它选填；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：123&lt;/font&gt;
    app_auth_code = ""
    # 应用授权令牌应用授权令牌，操作类型为1-刷新令牌时，且该字段有值，将与数据库值进行校验；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：202208200312104378&lt;/font&gt;
    app_auth_token = ""

    def post(self, extend_infos):
        """
        支付宝直连-换取应用授权令牌

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "app_id":self.app_id,
            "oper_type":self.oper_type,
            "app_auth_code":self.app_auth_code,
            "app_auth_token":self.app_auth_token
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_DIRECT_ALIPAY_APPAUTHTOKEN_EXCHANGE, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_ELEC_CARD_BIND



class V2MerchantElecCardBindRequest(object):
    """
    电子账户绑卡
    """

    # 请求流水号
    req_seq_id = ""
    # 请求时间
    req_date = ""
    # 汇付Id
    huifu_id = ""
    # 电子卡信息
    elec_card_info = ""

    def post(self, extend_infos):
        """
        电子账户绑卡

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "elec_card_info":self.elec_card_info
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_ELEC_CARD_BIND, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_BUSI_EFPCONFIG



class V2MerchantBusiEfpconfigRequest(object):
    """
    全渠道资金管理配置
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 商户汇付id
    huifu_id = ""
    # 所属渠道商
    upper_huifu_id = ""
    # 开关
    switch_state = ""
    # 自动入账开关0:关闭 1:开通；switch_state为1时必填；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：1&lt;/font&gt;
    out_order_auto_acct_flag = ""
    # 支付手续费外扣汇付ID支付手续费外扣标记为1时必填；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：6666000109812123&lt;/font&gt;
    out_fee_huifuid = ""
    # 全域资金开户使用的银行卡信息首次开通时必填 jsonObject格式
    out_order_acct_card = ""
    # 全域资金开户手续费首次开通时必填 jsonObject格式
    out_order_acct_open_fees = ""
    # 全渠道资金管理补充材料id涉及文件类型：[F504-全渠道资金管理补充材料](https://paas.huifu.com/open/doc/api/#/csfl/api_csfl_wjlx)；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：57cc7f00-600a-33ab-b614-6221bbf2e530&lt;/font&gt;
    other_payment_institutions_pic = ""
    # 新网银行数字证书及电子签名授权委托书out_funds_gate_id为xw0时必填；涉及文件类型：[F534-银行数字证书及电子签名授权委托书](https://paas.huifu.com/open/doc/api/#/csfl/api_csfl_wjlx)；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：57cc7f00-600a-33ab-b614-6221bbf2e530&lt;/font&gt;
    xw_digital_certificate_pic = ""
    # 银行类型
    out_funds_gate_id = ""
    # 签约人信息switch_state为1时必填 jsonObject格式
    sign_user_info = ""
    # 入账来源
    acct_source = ""

    def post(self, extend_infos):
        """
        全渠道资金管理配置

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "upper_huifu_id":self.upper_huifu_id,
            "switch_state":self.switch_state,
            "out_order_auto_acct_flag":self.out_order_auto_acct_flag,
            "out_fee_huifuid":self.out_fee_huifuid,
            "out_order_acct_card":self.out_order_acct_card,
            "out_order_acct_open_fees":self.out_order_acct_open_fees,
            "other_payment_institutions_pic":self.other_payment_institutions_pic,
            "xw_digital_certificate_pic":self.xw_digital_certificate_pic,
            "out_funds_gate_id":self.out_funds_gate_id,
            "sign_user_info":self.sign_user_info,
            "acct_source":self.acct_source
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_BUSI_EFPCONFIG, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_BANKINSTALLMENTINFO_QUERY



class V2TradeBankinstallmentinfoQueryRequest(object):
    """
    银行卡分期支持银行查询
    """

    # 页码
    page_num = ""
    # 每页条数
    page_size = ""
    # 产品号
    product_id = ""

    def post(self, extend_infos):
        """
        银行卡分期支持银行查询

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "page_num":self.page_num,
            "page_size":self.page_size,
            "product_id":self.product_id
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_BANKINSTALLMENTINFO_QUERY, required_params, need_verfy_sign=False)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_SETTLE_COLLECTION_DETAIL_QUERY



class V2TradeSettleCollectionDetailQueryRequest(object):
    """
    资金归集明细查询
    """

    # 请求日期
    req_date = ""
    # 请求流水号
    req_seq_id = ""
    # 开始日期
    begin_date = ""
    # 结束日期
    end_date = ""
    # 转出方商户号转出方商户号和转入方商户号必填一个；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：6666000123123124&lt;/font&gt;
    out_huifu_id = ""
    # 转入方商户号转出方商户号和转入方商户号必填一个；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：6666000123123124&lt;/font&gt;
    in_huifu_id = ""

    def post(self, extend_infos):
        """
        资金归集明细查询

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_date":self.req_date,
            "req_seq_id":self.req_seq_id,
            "begin_date":self.begin_date,
            "end_date":self.end_date,
            "out_huifu_id":self.out_huifu_id,
            "in_huifu_id":self.in_huifu_id
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_SETTLE_COLLECTION_DETAIL_QUERY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_INVOICE_SELFSCANOPEN



class V2InvoiceSelfscanopenRequest(object):
    """
    自助扫码开票
    """

    # 请求流水号
    req_seq_id = ""
    # 请求时间
    req_date = ""
    # 汇付商户号
    huifu_id = ""
    # 发票类型
    ivc_type = ""
    # 开票类型
    open_type = ""
    # 含税合计金额（元）
    order_amt = ""
    # 开票商品信息
    goods_infos = ""
    # 开票人信息
    payer_info = ""

    def post(self, extend_infos):
        """
        自助扫码开票

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "ivc_type":self.ivc_type,
            "open_type":self.open_type,
            "order_amt":self.order_amt,
            "goods_infos":self.goods_infos,
            "payer_info":self.payer_info
        }
        required_params.update(extend_infos)
        return request_post(V2_INVOICE_SELFSCANOPEN, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_WALLET_TRADE_PAY_BALANCE



class V2WalletTradePayBalanceRequest(object):
    """
    钱包支付下单
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 商户号
    huifu_id = ""
    # 钱包用户ID
    user_huifu_id = ""
    # 订单金额
    trans_amt = ""
    # 跳转地址
    front_url = ""

    def post(self, extend_infos):
        """
        钱包支付下单

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "user_huifu_id":self.user_huifu_id,
            "trans_amt":self.trans_amt,
            "front_url":self.front_url
        }
        required_params.update(extend_infos)
        return request_post(V2_WALLET_TRADE_PAY_BALANCE, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_ACCTPAYMENT_ACCTLOG_QUERY



class V2TradeAcctpaymentAcctlogQueryRequest(object):
    """
    账务流水查询
    """

    # 请求流水号
    req_seq_id = ""
    # 渠道/代理/商户/用户编号
    huifu_id = ""
    # 账务日期
    acct_date = ""

    def post(self, extend_infos):
        """
        账务流水查询

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "huifu_id":self.huifu_id,
            "acct_date":self.acct_date
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_ACCTPAYMENT_ACCTLOG_QUERY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_LARGEAMT_BINDCARD_BIND



class V2LargeamtBindcardBindRequest(object):
    """
    银行大额支付绑卡
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 商户号
    huifu_id = ""
    # 卡类型
    card_type = ""
    # 银行账户名
    card_name = ""
    # 银行卡号密文
    card_no = ""
    # 银行编码
    bank_code = ""

    def post(self, extend_infos):
        """
        银行大额支付绑卡

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "card_type":self.card_type,
            "card_name":self.card_name,
            "card_no":self.card_no,
            "bank_code":self.bank_code
        }
        required_params.update(extend_infos)
        return request_post(V2_LARGEAMT_BINDCARD_BIND, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_ONLINEPAYMENT_WAPPAY



class V2TradeOnlinepaymentWappayRequest(object):
    """
    手机WAP支付
    """

    # 请求日期
    req_date = ""
    # 请求流水号
    req_seq_id = ""
    # 商户号
    huifu_id = ""
    # 交易金额
    trans_amt = ""
    # 分期期数分期支付时必填；支持：03、06、12、24；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：03&lt;/font&gt;；&lt;br/&gt;空值时是wap支付；
    instalments_num = ""
    # 银行卡号instalments_num不为空时必填；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：6228480031509440000&lt;/font&gt;
    bank_card_no = ""
    # 网联扩展数据
    extend_pay_data = ""
    # 安全信息
    risk_check_data = ""
    # 设备信息
    terminal_device_data = ""
    # 页面跳转地址
    front_url = ""
    # 异步通知地址
    notify_url = ""

    def post(self, extend_infos):
        """
        手机WAP支付

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_date":self.req_date,
            "req_seq_id":self.req_seq_id,
            "huifu_id":self.huifu_id,
            "trans_amt":self.trans_amt,
            "instalments_num":self.instalments_num,
            "bank_card_no":self.bank_card_no,
            "extend_pay_data":self.extend_pay_data,
            "risk_check_data":self.risk_check_data,
            "terminal_device_data":self.terminal_device_data,
            "front_url":self.front_url,
            "notify_url":self.notify_url
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_ONLINEPAYMENT_WAPPAY, required_params, need_verfy_sign=False)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_WALLET_TRADE_ORDER_CLOSE



class V2WalletTradeOrderCloseRequest(object):
    """
    钱包关单
    """

    # 请求流水号
    req_seq_id = ""
    # 请求时间
    req_date = ""
    # 商户号
    huifu_id = ""
    # 原交易全局流水号org_hf_seq_id，org_req_seq_id二选一；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：00470topo1A221019132207P068ac1362af00000&lt;/font&gt;
    org_hf_seq_id = ""
    # 原交易请求流水号org_hf_seq_id，org_req_seq_id二选一；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：rQ2021121311173944134649875651&lt;/font&gt;
    org_req_seq_id = ""
    # 原交易请求日期
    org_req_date = ""

    def post(self, extend_infos):
        """
        钱包关单

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "org_hf_seq_id":self.org_hf_seq_id,
            "org_req_seq_id":self.org_req_seq_id,
            "org_req_date":self.org_req_date
        }
        required_params.update(extend_infos)
        return request_post(V2_WALLET_TRADE_ORDER_CLOSE, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_CLOUDMIS_DEVICE_INFORMATION_MIS



class V2TradeCloudmisDeviceInformationMisRequest(object):
    """
    终端云MIS交易
    """

    # 终端设备号
    device_id = ""
    # 商户号
    huifu_id = ""
    # 交易信息
    json_data = ""

    def post(self, extend_infos):
        """
        终端云MIS交易

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "device_id":self.device_id,
            "huifu_id":self.huifu_id,
            "json_data":self.json_data
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_CLOUDMIS_DEVICE_INFORMATION_MIS, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_PAYMENT_ZXE_UNKNOWNINCOME_DISPOSE



class V2TradePaymentZxeUnknownincomeDisposeRequest(object):
    """
    不明来账处理
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 商户号
    huifu_id = ""
    # 银行侧交易流水号
    bank_serial_no = ""
    # 操作类型
    operate_type = ""

    def post(self, extend_infos):
        """
        不明来账处理

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "bank_serial_no":self.bank_serial_no,
            "operate_type":self.operate_type
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_PAYMENT_ZXE_UNKNOWNINCOME_DISPOSE, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_PAYAFTERUSE_CREDITBIZORDER_CREATE



class V2TradePayafteruseCreditbizorderCreateRequest(object):
    """
    服务单创建
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 商户号
    huifu_id = ""
    # 订单总金额
    trans_amt = ""
    # 追踪ID
    source_id = ""
    # 支付宝用户ID
    buyer_id = ""
    # 订单标题
    title = ""
    # 订单类型
    merchant_biz_type = ""
    # 订单详情地址
    path = ""
    # 芝麻信用服务ID
    zm_service_id = ""
    # 商品详细信息
    item_infos = ""

    def post(self, extend_infos):
        """
        服务单创建

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "trans_amt":self.trans_amt,
            "source_id":self.source_id,
            "buyer_id":self.buyer_id,
            "title":self.title,
            "merchant_biz_type":self.merchant_biz_type,
            "path":self.path,
            "zm_service_id":self.zm_service_id,
            "item_infos":self.item_infos
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_PAYAFTERUSE_CREDITBIZORDER_CREATE, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_ACTIVITY_ADD



class V2MerchantActivityAddRequest(object):
    """
    商户活动报名
    """

    # 请求日期
    req_date = ""
    # 请求流水号
    req_seq_id = ""
    # 汇付客户Id
    huifu_id = ""
    # 营业执照图片调用[图片上传接口](http://paas.huifu.com/open/doc/api/#/shgl/shjj/api_shjj_shtpsc)获取jfile文件id；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：57cc7f00-600a-33ab-b614-6221bbf2e529&lt;/font&gt;&lt;br/&gt;活动类型为支付宝谷雨活动时无需填写任何资料
    bl_photo = ""
    # 店内环境图片参加教育食堂、非校园餐饮、非盈利、停车缴费行业时必传；调用[图片上传接口](http://paas.huifu.com/open/doc/api/#/shgl/shjj/api_shjj_shtpsc)获取jfile文件id；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：57cc7f00-600a-33ab-b614-6221bbf2e529&lt;/font&gt;&lt;br/&gt;活动类型为支付宝谷雨活动时无需填写任何资料
    dh_photo = ""
    # 手续费类型
    fee_type = ""
    # 整体门面图片（门头照）参加教育食堂行业、非校园餐饮、非盈利、线下教培、公办医院、商业医疗时必传；调用[图片上传接口](http://paas.huifu.com/open/doc/api/#/shgl/shjj/api_shjj_shtpsc)获取jfile文件id；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：57cc7f00-600a-33ab-b614-6221bbf2e529&lt;/font&gt;&lt;br/&gt;活动类型为支付宝谷雨活动时无需填写任何资料
    mm_photo = ""
    # 收银台照片参加教育食堂行业、线下教培、公办医院时必传；调用[图片上传接口](http://paas.huifu.com/open/doc/api/#/shgl/shjj/api_shjj_shtpsc)获取jfile文件id；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：57cc7f00-600a-33ab-b614-6221bbf2e529&lt;/font&gt;&lt;br/&gt;活动类型为支付宝谷雨活动时无需填写任何资料
    syt_photo = ""
    # 支付通道
    pay_way = ""

    def post(self, extend_infos):
        """
        商户活动报名

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_date":self.req_date,
            "req_seq_id":self.req_seq_id,
            "huifu_id":self.huifu_id,
            "bl_photo":self.bl_photo,
            "dh_photo":self.dh_photo,
            "fee_type":self.fee_type,
            "mm_photo":self.mm_photo,
            "syt_photo":self.syt_photo,
            "pay_way":self.pay_way
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_ACTIVITY_ADD, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_BILL_ENT_CREATE



class V2BillEntCreateRequest(object):
    """
    创建企业账单
    """

    # 请求流水号
    req_seq_id = ""
    # 请求时间
    req_date = ""
    # 商户号
    huifu_id = ""
    # 付款人
    payer_id = ""
    # 账单名称
    bill_name = ""
    # 账单金额
    bill_amt = ""
    # 可支持的付款方式
    support_pay_type = ""
    # 账单截止日期
    bill_end_date = ""
    # 收款人信息
    payee_info = ""

    def post(self, extend_infos):
        """
        创建企业账单

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "payer_id":self.payer_id,
            "bill_name":self.bill_name,
            "bill_amt":self.bill_amt,
            "support_pay_type":self.support_pay_type,
            "bill_end_date":self.bill_end_date,
            "payee_info":self.payee_info
        }
        required_params.update(extend_infos)
        return request_post(V2_BILL_ENT_CREATE, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_QUICKBUCKLE_BIND_CARDINFO_QUERY



class V2QuickbuckleBindCardinfoQueryRequest(object):
    """
    一键绑卡-工行卡号查询
    """

    # 请求流水号
    req_seq_id = ""
    # 请求时间
    req_date = ""
    # 汇付Id
    huifu_id = ""
    # 产品Id
    product_id = ""
    # 银行卡开户姓名
    card_name = ""
    # 身份证类型
    cert_type = ""
    # 银行卡绑定身份证
    cert_no = ""
    # 银行卡绑定手机号
    card_mobile = ""
    # 回调地址
    notify_url = ""

    def post(self, extend_infos):
        """
        一键绑卡-工行卡号查询

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "product_id":self.product_id,
            "card_name":self.card_name,
            "cert_type":self.cert_type,
            "cert_no":self.cert_no,
            "card_mobile":self.card_mobile,
            "notify_url":self.notify_url
        }
        required_params.update(extend_infos)
        return request_post(V2_QUICKBUCKLE_BIND_CARDINFO_QUERY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_PAYSCORE_SERVICEORDER_COMPLETE



class V2TradePayscoreServiceorderCompleteRequest(object):
    """
    完结支付分订单
    """

    # 汇付商户号
    huifu_id = ""
    # 汇付订单号
    out_order_no = ""
    # 完结金额
    ord_amt = ""
    # 服务时间
    time_range = ""

    def post(self, extend_infos):
        """
        完结支付分订单

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "huifu_id":self.huifu_id,
            "out_order_no":self.out_order_no,
            "ord_amt":self.ord_amt,
            "time_range":self.time_range
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_PAYSCORE_SERVICEORDER_COMPLETE, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_BUSI_CONFIG



class V2MerchantBusiConfigRequest(object):
    """
    微信商户配置
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 汇付客户Id
    huifu_id = ""
    # 业务开通类型
    fee_type = ""
    # 公众号支付Appid条件必填，&lt;font color&#x3D;&quot;green&quot;&gt;示例值：wx3767c5bd01df5061&lt;/font&gt; ；wx_woa_app_id 、wx_woa_path、micro_sub_appid和 wx_applet_app_id四者不能同时为空
    wx_woa_app_id = ""
    # 微信公众号授权目录条件必填，&lt;font color&#x3D;&quot;green&quot;&gt;示例值：https://paas.huifu.com/shouyintai/demo/h5/&lt;/font&gt;；wx_woa_app_id 、wx_woa_path、micro_sub_appid和 wx_applet_app_id四者不能同时为空
    wx_woa_path = ""
    # 微信小程序APPID条件必填，&lt;font color&#x3D;&quot;green&quot;&gt;示例值：wx8523175fea790f10&lt;/font&gt; ；wx_woa_app_id 、wx_woa_path、micro_sub_appid和 wx_applet_app_id四者不能同时为空
    wx_applet_app_id = ""

    def post(self, extend_infos):
        """
        微信商户配置

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "fee_type":self.fee_type,
            "wx_woa_app_id":self.wx_woa_app_id,
            "wx_woa_path":self.wx_woa_path,
            "wx_applet_app_id":self.wx_applet_app_id
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_BUSI_CONFIG, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V3_TRADE_ONLINEPAYMENT_QUICKPAY_PAY



class V3TradeOnlinepaymentQuickpayPayRequest(object):
    """
    快捷支付
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 商户号
    huifu_id = ""
    # 短信验证码
    sms_code = ""

    def post(self, extend_infos):
        """
        快捷支付

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "sms_code":self.sms_code
        }
        required_params.update(extend_infos)
        return request_post(V3_TRADE_ONLINEPAYMENT_QUICKPAY_PAY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_PAYMENT_DELAYTRANS_CONFIRM



class V2TradePaymentDelaytransConfirmRequest(object):
    """
    交易确认接口
    """

    # 请求日期
    req_date = ""
    # 请求流水号
    req_seq_id = ""
    # 商户号
    huifu_id = ""
    # 交易类型**原交易为快捷支付必填：QUICK_PAY**，&lt;br/&gt;**原交易为余额支付必填：ACCT_PAYMENT**；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：ACCT_PAYMENT&lt;/font&gt;
    pay_type = ""

    def post(self, extend_infos):
        """
        交易确认接口

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_date":self.req_date,
            "req_seq_id":self.req_seq_id,
            "huifu_id":self.huifu_id,
            "pay_type":self.pay_type
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_PAYMENT_DELAYTRANS_CONFIRM, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_BUSI_REALNAME



class V2MerchantBusiRealnameRequest(object):
    """
    微信实名认证
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 汇付ID
    huifu_id = ""
    # 联系人姓名
    name = ""
    # 联系人手机号
    mobile = ""
    # 联系人身份证号码
    id_card_number = ""
    # 联系人类型
    contact_type = ""

    def post(self, extend_infos):
        """
        微信实名认证

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "name":self.name,
            "mobile":self.mobile,
            "id_card_number":self.id_card_number,
            "contact_type":self.contact_type
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_BUSI_REALNAME, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_QUICKBUCKLE_ONEKEY_CARDBIND



class V2QuickbuckleOnekeyCardbindRequest(object):
    """
    一键绑卡
    """

    # 请求流水号
    req_seq_id = ""
    # 请求时间
    req_date = ""
    # 汇付Id
    huifu_id = ""
    # 顾客用户号 
    out_cust_id = ""
    # 银行号
    bank_id = ""
    # 银行卡开户姓名 
    card_name = ""
    # 银行卡绑定身份证
    cert_id = ""
    # 银行卡绑定证件类型
    cert_type = ""
    # 证件有效期到期日长期有效不填.格式：yyyyMMdd。&lt;font color&#x3D;&quot;green&quot;&gt;示例值：20311111&lt;/font&gt;
    cert_end_date = ""
    # 银行卡绑定手机号 
    card_mp = ""
    # 卡的借贷类型
    dc_type = ""
    # 异步请求地址
    async_return_url = ""
    # 设备信息域
    trx_device_inf = ""

    def post(self, extend_infos):
        """
        一键绑卡

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "out_cust_id":self.out_cust_id,
            "bank_id":self.bank_id,
            "card_name":self.card_name,
            "cert_id":self.cert_id,
            "cert_type":self.cert_type,
            "cert_end_date":self.cert_end_date,
            "card_mp":self.card_mp,
            "dc_type":self.dc_type,
            "async_return_url":self.async_return_url,
            "trx_device_inf":self.trx_device_inf
        }
        required_params.update(extend_infos)
        return request_post(V2_QUICKBUCKLE_ONEKEY_CARDBIND, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_INVOICE_MER_AUTHQRCODE_QUERY



class V2InvoiceMerAuthqrcodeQueryRequest(object):
    """
    查询人脸认证结果
    """

    # 请求流水号
    req_seq_id = ""
    # 请求时间
    req_date = ""
    # 开票方汇付ID
    huifu_id = ""

    def post(self, extend_infos):
        """
        查询人脸认证结果

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id
        }
        required_params.update(extend_infos)
        return request_post(V2_INVOICE_MER_AUTHQRCODE_QUERY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_PAYMENT_GETELECTRONICRECEIPT



class V2TradePaymentGetelectronicreceiptRequest(object):
    """
    电子回单查询
    """

    # 商户号
    huifu_id = ""
    # 是否展示手续费0:不展示手续费，1:展示手续费；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：0&lt;/font&gt;&lt;br/&gt;模板类型1或2时必填；
    show_feemat = ""
    # 交易返回的全局流水号1、交易类返回的全局流水号。org_hf_seq_id与（org_req_seq_id、org_req_date、pay_type） 不能同时为空；&lt;br/&gt;2、结算（SETTLE）返回的结算流水编号&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：003500TOP2B211021163242P447ac132fd200000&lt;/font&gt;
    org_hf_seq_id = ""
    # 原交易请求日期格式:yyyyMMdd；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：20221022&lt;/font&gt;
    org_req_date = ""
    # 原交易请求流水号org_hf_seq_id与（org_req_seq_id、org_req_date、pay_type） 不能同时为空；&lt;font color&#x3D;&quot;green&quot;&gt;示例值：2022012614120615001&lt;/font&gt;
    org_req_seq_id = ""
    # 支付类型BALANCE_PAY：余额支付，&lt;br/&gt;CASHOUT：取现，&lt;br/&gt;QUICK_PAY：快捷支付，&lt;br/&gt;ONLINE_PAY：网银，&lt;br/&gt;SURROGATE：代发&lt;br/&gt;WITHHOLD_PAY：代扣&lt;br/&gt;WAP_PAY：手机WAP&lt;br/&gt;PAY_CONFIRM：交易确认&lt;br/&gt;TRANSFER_ACCT：大额转账(指[银行大额转账](https://paas.huifu.com/open/doc/api/#/dejy/api_dejy_yhdezz)交易)&lt;br/&gt;T_MICROPAY: 微信反扫&lt;br/&gt;A_MICROPAY: 支付宝反扫&lt;br/&gt;T_JSAPI: 微信公众号支付&lt;br/&gt;T_MINIAPP: 微信小程序支付&lt;br/&gt;T_APP：微信APP支付&lt;br/&gt;A_JSAPI: 支付宝JS支付&lt;br/&gt;A_NATIVE: 支付宝正扫支付&lt;br/&gt;T_H5：微信直连H5支付&lt;br/&gt;SETTLE：结算&lt;br/&gt;JDBT：京东白条&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：ONLINE_PAY&lt;/font&gt;&lt;br/&gt;注意：支付类型有值，原交易请求流水号不为空必填； &lt;br/&gt;选择交易确认类型时：请传入交易确认的请求流水号或全局流水号。&lt;br/&gt;模板类型为3时，忽略支付类型取值；
    pay_type = ""

    def post(self, extend_infos):
        """
        电子回单查询

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "huifu_id":self.huifu_id,
            "show_feemat":self.show_feemat,
            "org_hf_seq_id":self.org_hf_seq_id,
            "org_req_date":self.org_req_date,
            "org_req_seq_id":self.org_req_seq_id,
            "pay_type":self.pay_type
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_PAYMENT_GETELECTRONICRECEIPT, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_INVOICE_PERMISSION_QUERY



class V2InvoicePermissionQueryRequest(object):
    """
    电子发票业务开通查询
    """

    # 请求流水号
    req_seq_id = ""
    # 请求时间
    req_date = ""
    # 商户汇付Id
    huifu_id = ""
    # 是否包含下级
    include_sub_flag = ""
    # 当前页
    page_num = ""
    # 分页大小
    page_size = ""

    def post(self, extend_infos):
        """
        电子发票业务开通查询

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "include_sub_flag":self.include_sub_flag,
            "page_num":self.page_num,
            "page_size":self.page_size
        }
        required_params.update(extend_infos)
        return request_post(V2_INVOICE_PERMISSION_QUERY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_DIRECT_ZFT_RECEIVER_QUERY



class V2MerchantDirectZftReceiverQueryRequest(object):
    """
    直付通分账关系查询
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 汇付ID
    huifu_id = ""
    # 开发者的应用ID
    app_id = ""
    # 每页数目
    page_size = ""
    # 页数
    page_num = ""

    def post(self, extend_infos):
        """
        直付通分账关系查询

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "app_id":self.app_id,
            "page_size":self.page_size,
            "page_num":self.page_num
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_DIRECT_ZFT_RECEIVER_QUERY, required_params)



# 以下为接口uri

# 分期支付
V2_TRADE_INSTALLMENT_PAYMENT = "/v2/trade/installment/payment"

# 快捷支付
V3_TRADE_ONLINEPAYMENT_QUICKPAY_PAY = "/v3/trade/onlinepayment/quickpay/pay"

# 快捷短信发送
V3_TRADE_ONLINEPAYMENT_QUICKPAY_SMSSEND = "/v3/trade/onlinepayment/quickpay/smssend"

# 电子账户余额查询
V2_BANK_BALANCE_QUERY = "/v2/bank/balance/query"

# 不明来账列表查询
V2_TRADE_PAYMENT_ZXE_UNKNOWNINCOME_QUERY = "/v2/trade/payment/zxe/unknownincome/query"

# 不明来账处理结果查询
V2_TRADE_PAYMENT_ZXE_UNKNOWNINCOME_DISPOSEQUERY = "/v2/trade/payment/zxe/unknownincome/disposequery"

# 不明来账处理
V2_TRADE_PAYMENT_ZXE_UNKNOWNINCOME_DISPOSE = "/v2/trade/payment/zxe/unknownincome/dispose"

# 服务单关闭
V2_TRADE_PAYAFTERUSE_CREDITBIZORDER_CLOSE = "/v2/trade/payafteruse/creditbizorder/close"

# 服务单查询
V2_TRADE_PAYAFTERUSE_CREDITBIZORDER_QUERY = "/v2/trade/payafteruse/creditbizorder/query"

# 服务单创建
V2_TRADE_PAYAFTERUSE_CREDITBIZORDER_CREATE = "/v2/trade/payafteruse/creditbizorder/create"

# 分期扣款查询
V2_TRADE_PAYAFTERUSE_INSTALLMENT_QUERY = "/v2/trade/payafteruse/installment/query"

# 分期扣款
V2_TRADE_PAYAFTERUSE_INSTALLMENT_PAY = "/v2/trade/payafteruse/installment/pay"

# 分期交易退款查询
V2_TRADE_PAYAFTERUSE_INSTALLMENT_REFUNDQUERY = "/v2/trade/payafteruse/installment/refundquery"

# 分期交易退款
V2_TRADE_PAYAFTERUSE_INSTALLMENT_REFUND = "/v2/trade/payafteruse/installment/refund"

# 分期单创建
V2_TRADE_PAYAFTERUSE_INSTALLMENT_CREATE = "/v2/trade/payafteruse/installment/create"

# 云MIS订单详情查询接口
V2_TRADE_CLOUDMIS_ORDER_DETAIL = "/v2/trade/cloudmis/order/detail"

# 终端云MIS交易
V2_TRADE_CLOUDMIS_DEVICE_INFORMATION_MIS = "/v2/trade/cloudmis/device/information/mis"

# 新建付款人
V2_BILL_ENT_PAYER_CREATE = "/v2/bill/ent/payer/create"

# 修改付款人信息
V2_BILL_ENT_PAYER_UPDATE = "/v2/bill/ent/payer/update"

# 删除付款人
V2_BILL_ENT_PAYER_DELETE = "/v2/bill/ent/payer/delete"

# 企业账单状态变更
V2_BILL_ENT_CHANGESTAT = "/v2/bill/ent/changeStat"

# 企业账单退款查询
V2_BILL_ENT_REFUND_QUERY = "/v2/bill/ent/refund/query"

# 企业账单退款
V2_BILL_ENT_REFUND = "/v2/bill/ent/refund"

# 企业账单查询
V2_BILL_ENT_QUERY = "/v2/bill/ent/query"

# 付款人查询
V2_BILL_ENT_PAYER_QUERY = "/v2/bill/ent/payer/query"

# 创建企业账单
V2_BILL_ENT_CREATE = "/v2/bill/ent/create"

# 申诉单详情查询
V2_MERCHANT_APPEAL_DETAIL_QUERY = "/v2/merchant/appeal/detail/query"

# 提交申诉
V2_MERCHANT_APPEAL_COMMON_SUBMIT = "/v2/merchant/appeal/common/submit"

# 申诉文件url查询
V2_MERCHANT_APPEAL_FILEURL_QUERY = "/v2/merchant/appeal/fileurl/query"

# 申诉单列表查询
V2_MERCHANT_APPEAL_LIST_QUERY = "/v2/merchant/appeal/list/query"

# 申诉客户信息查询
V2_MERCHANT_APPEAL_CUSTINFO_QUERY = "/v2/merchant/appeal/custinfo/query"

# 关联线索查询
V2_MERCHANT_APPEAL_RELATEDCLUE_QUERY = "/v2/merchant/appeal/relatedclue/query"

# 操作日志查询
V2_MERCHANT_APPEAL_LOG_QUERY = "/v2/merchant/appeal/log/query"

# 快捷绑卡申请接口
V3_QUICKBUCKLE_APPLY = "/v3/quickbuckle/apply"

# 快捷绑卡确认接口
V3_QUICKBUCKLE_CONFIRM = "/v3/quickbuckle/confirm"

# 新增归集配置
V2_TRADE_SETTLE_COLLECTION_RULE_ADD = "/v2/trade/settle/collection/rule/add"

# 修改归集配置
V2_TRADE_SETTLE_COLLECTION_RULE_MODIFY = "/v2/trade/settle/collection/rule/modify"

# 归集配置查询
V2_TRADE_SETTLE_COLLECTION_RULE_QUERY = "/v2/trade/settle/collection/rule/query"

# 资金归集明细查询
V2_TRADE_SETTLE_COLLECTION_DETAIL_QUERY = "/v2/trade/settle/collection/detail/query"

# 灵工微信代发查询
V2_TRADE_LGWX_SURROGATE_QUERY = "/v2/trade/lgwx/surrogate/query"

# 灵工微信代发
V2_TRADE_LGWX_SURROGATE = "/v2/trade/lgwx/surrogate"

# 银行大额支付解绑
V2_LARGEAMT_BINDCARD_UNBIND = "/v2/largeamt/bindcard/unbind"

# 银行大额支付绑卡查询
V2_LARGEAMT_BINDCARD_QUERY = "/v2/largeamt/bindcard/query"

# 银行大额支付绑卡
V2_LARGEAMT_BINDCARD_BIND = "/v2/largeamt/bindcard/bind"

# 上传短信验证码
V2_INVOICE_MER_VERIFYCODE_UPLOAD = "/v2/invoice/mer/verifycode/upload"

# 获取人脸认证二维码
V2_INVOICE_MER_AUTHQRCODE_GRANT = "/v2/invoice/mer/authqrcode/grant"

# 查询人脸认证结果
V2_INVOICE_MER_AUTHQRCODE_QUERY = "/v2/invoice/mer/authqrcode/query"

# 用户列表查询
V2_USER_LIST_QUERY = "/v2/user/list/query"

# 电子发票业务开通查询
V2_INVOICE_PERMISSION_QUERY = "/v2/invoice/permission/query"

# 电子发票业务开通
V2_INVOICE_PERMISSION_GRANT = "/v2/invoice/permission/grant"

# 商户注册状态查询
V2_INVOICE_MER_STATUS_QUERY = "/v2/invoice/mer/status/query"

# 商户注册信息修改
V2_INVOICE_MER_MODIFY = "/v2/invoice/mer/modify"

# 商户注册信息查询
V2_INVOICE_MER_QUERY = "/v2/invoice/mer/query"

# 商户注册
V2_INVOICE_MER_REG = "/v2/invoice/mer/reg"

# 开票员登录
V2_INVOICE_CLERK_LOGON = "/v2/invoice/clerk/logon"

# 开票员登记
V2_INVOICE_CLERK_REG = "/v2/invoice/clerk/reg"

# 完税凭证下载
V2_HYC_TAX_DOWNLOAD = "/v2/hyc/tax/download"

# 用户申请单状态查询
V2_USER_APPLY_QUERY = "/v2/user/apply/query"

# 开通下级商户权限配置接口
V2_MERCHANT_BUSI_HEAD_CONFIG = "/v2/merchant/busi/head/config"

# 一键绑卡-工行卡号查询
V2_QUICKBUCKLE_BIND_CARDINFO_QUERY = "/v2/quickbuckle/bind/cardInfo/query"

# 完税凭证查询
V2_HYC_TAX_QUERY = "/v2/hyc/tax/query"

# 申请开票
V2_HYC_INVOICE_APPLY = "/v2/hyc/invoice/apply"

# 商户签约查询
V2_HYC_MERSIGN_QUERY = "/v2/hyc/mersign/query"

# 开票信息查询
V2_HYC_INVINFO_QUERY = "/v2/hyc/invinfo/query"

# 开票类目查询
V2_HYC_INVCATEGORY_QUERY = "/v2/hyc/invcategory/query"

# 个人签约状态查询
V2_HYC_CONTRACT_QUERY = "/v2/hyc/contract/query"

# 个人签约发起
V2_HYC_PERSONSIGN_CREATE = "/v2/hyc/personsign/create"

# 用户补贴
V2_WALLET_TRADE_RECHARGE_TRANSFER = "/v2/wallet/trade/recharge/transfer"

# 钱包关单
V2_WALLET_TRADE_ORDER_CLOSE = "/v2/wallet/trade/order/close"

# 自助扫码开票
V2_INVOICE_SELFSCANOPEN = "/v2/invoice/selfscanopen"

# 发票开具状态查询
V2_INVOICE_QUERYAPPLY = "/v2/invoice/queryapply"

# 发票开具
V2_INVOICE_OPEN = "/v2/invoice/open"

# 全渠道资金管理配置查询
V2_MERCHANT_BUSI_EFPDETAIL = "/v2/merchant/busi/efpdetail"

# 全渠道资金管理配置
V2_MERCHANT_BUSI_EFPCONFIG = "/v2/merchant/busi/efpconfig"

# 银行大额未入账流水列表查询
V2_TRADE_ONLINEPAYMENT_TRANSFER_BANKBLOTTER_QUERY = "/v2/trade/onlinepayment/transfer/bankblotter/query"

# 托管交易退款查询
V2_TRADE_HOSTING_PAYMENT_QUERYREFUNDINFO = "/v2/trade/hosting/payment/queryRefundInfo"

# 托管交易退款
V2_TRADE_HOSTING_PAYMENT_HTREFUND = "/v2/trade/hosting/payment/htRefund"

# 托管交易查询
V2_TRADE_HOSTING_PAYMENT_QUERYORDERINFO = "/v2/trade/hosting/payment/queryorderinfo"

# E账户转账及充值查询接口
V2_TRADE_PAYMENT_ZXE_INCASH_QUERY = "/v2/trade/payment/zxe/incash/query"

# 电子账户账务明细查询
V2_TRADE_PAYMENT_ZXE_ACCTDETAIL_QUERY = "/v2/trade/payment/zxe/acctdetail/query"

# 付款关系提交
V2_TRADE_PAYRELATION_APPLY = "/v2/trade/payrelation/apply"

# 电子账户设置默认卡
V2_MERCHANT_ELEC_CARD_DEFAULT = "/v2/merchant/elec/card/default"

# 电子账户解绑
V2_MERCHANT_ELEC_CARD_UNBIND = "/v2/merchant/elec/card/unbind"

# 电子账户绑卡
V2_MERCHANT_ELEC_CARD_BIND = "/v2/merchant/elec/card/bind"

# 钱包转账下单
V2_WALLET_TRADE_TRANSFER = "/v2/wallet/trade/transfer"

# 钱包支付退款查询
V2_WALLET_TRADE_PAY_REFUND_QUERY = "/v2/wallet/trade/pay/refund/query"

# 快捷绑卡查询
V2_QUICKBUCKLE_QUERY = "/v2/quickbuckle/query"

# 钱包转账下单
V2_WALLET_TRANSFER = "/v2/wallet/transfer"

# 钱包支付下单
V2_WALLET_TRADE_PAY_BALANCE = "/v2/wallet/trade/pay/balance"

# 钱包支付退款查询
V2_WALLET_PAY_REFUND_QUERY = "/v2/wallet/pay/refund/query"

# 钱包支付退款
V2_WALLET_TRADE_PAY_REFUND = "/v2/wallet/trade/pay/refund"

# 新增绑定卡结果查询
V2_WALLET_CARD_QUERY = "/v2/wallet/card/query"

# 新增绑定银行卡
V2_WALLET_CARD_ADD = "/v2/wallet/card/add"

# 钱包提现下单
V2_WALLET_TRADE_WITHDRAWAL = "/v2/wallet/trade/withdrawal"

# 钱包绑定手机号验证
V2_WALLET_MOBILE_VERIFY = "/v2/wallet/mobile/verify"

# 钱包用户查询
V2_WALLET_QUERY = "/v2/wallet/query"

# 钱包开户
V2_WALLET_CREATE = "/v2/wallet/create"

# 钱包密码修改
V2_WALLET_PASSWORD_MODIFY = "/v2/wallet/password/modify"

# 钱包密码重置
V2_WALLET_PASSWORD_RESET = "/v2/wallet/password/reset"

# 钱包交易查询
V2_WALLET_TRADE_QUERY = "/v2/wallet/trade/query"

# 钱包绑卡充值下单
V2_WALLET_TRADE_RECHARGE_CARD = "/v2/wallet/trade/recharge/card"

# 银行大额支付差错申请查询
V2_TRADE_ONLINEPAYMENT_TRANSFER_BANKMISTAKE_APPLYQUERY = "/v2/trade/onlinepayment/transfer/bankmistake/applyquery"

# 银行大额支付差错申请
V2_TRADE_ONLINEPAYMENT_TRANSFER_BANKMISTAKE_APPLY = "/v2/trade/onlinepayment/transfer/bankmistake/apply"

# 支付分扣款
V2_TRADE_PAYSCORE_PAY_PAYSCOREPAY = "/v2/trade/payscore/pay/payscorepay"

# 完结支付分订单
V2_TRADE_PAYSCORE_SERVICEORDER_COMPLETE = "/v2/trade/payscore/serviceorder/complete"

# 取消支付分订单
V2_TRADE_PAYSCORE_SERVICEORDER_CANCEL = "/v2/trade/payscore/serviceorder/cancel"

# 登记扣款信息
V2_TRADE_PAYSCORE_DEDUCT_REGITSTER = "/v2/trade/payscore/deduct/regitster"

# 查询扣款信息
V2_TRADE_PAYSCORE_DEDUCT_QUERY = "/v2/trade/payscore/deduct/query"

# 查询支付分订单
V2_TRADE_PAYSCORE_SERVICEORDER_QUERY = "/v2/trade/payscore/serviceorder/query"

# 创建支付分订单
V2_TRADE_PAYSCORE_SERVICEORDER_CREATE = "/v2/trade/payscore/serviceorder/create"

# 银行列表查询
V2_QUICKBUCKLE_BANK_QUERY = "/v2/quickbuckle/bank/query"

# 统一进件页面版查询
V2_MERCHANT_BUSI_STATUS_QUERY = "/v2/merchant/busi/status/query"

# 商户短信发送
V2_MERCHANT_BASICDATA_SMS_SEND = "/v2/merchant/basicdata/sms/send"

# 批量出金交易查询
V2_TRADE_BATCHTRANSLOG_QUERY = "/v2/trade/batchtranslog/query"

# 快捷支付页面版
V2_TRADE_ONLINEPAYMENT_QUICKPAY_FRONTPAY = "/v2/trade/onlinepayment/quickpay/frontpay"

# 快捷支付短信预校验
V2_TRADE_ONLINEPAYMENT_QUICKPAY_SMSCHECK = "/v2/trade/onlinepayment/quickpay/smscheck"

# 交易确认退款查询
V2_TRADE_PAYMENT_DELAYTRANS_CONFIRMREFUNDQUERY = "/v2/trade/payment/delaytrans/confirmrefundquery"

# 跳转电子小票页面
V2_TRADE_ELECTRON_RECEIPTS_JUMPINFO = "/v2/trade/electron/receipts/jumpinfo"

# 图片上传
V2_TRADE_ELECTRON_RECEIPTS_PICTURE_UPLOAD = "/v2/trade/electron/receipts/picture/upload"

# 上传电子小票图片
V2_TRADE_ELECTRON_RECEIPTS_UPLOAD = "/v2/trade/electron/receipts/upload"

# 查询小票自定义入口
V2_TRADE_ELECTRON_RECEIPTS_CUSTOMENTRANCES_QUERY = "/v2/trade/electron/receipts/customentrances/query"

# 创建修改小票自定义入口
V2_TRADE_ELECTRON_RECEIPTS_CUSTOMENTRANCES_CREATE = "/v2/trade/electron/receipts/customentrances/create"

# 汇付入账确认
V2_TRADE_ONLINEPAYMENT_TRANSFER_REMITTANCE = "/v2/trade/onlinepayment/transfer/remittance"

# 汇付入账查询
V2_TRADE_ONLINEPAYMENT_TRANSFER_REMITTANCEORDER = "/v2/trade/onlinepayment/transfer/remittanceorder"

# 代扣支付
V2_TRADE_ONLINEPAYMENT_WITHHOLDPAY = "/v2/trade/onlinepayment/withholdpay"

# 代扣绑卡页面版
V2_QUICKBUCKLE_WITHHOLD_PAGE_GET = "/v2/quickbuckle/withhold/page/get"

# 代扣绑卡申请
V2_QUICKBUCKLE_WITHHOLD_APPLY = "/v2/quickbuckle/withhold/apply"

# 代扣绑卡查询
V2_QUICKBUCKLE_WITHHOLD_QUERY = "/v2/quickbuckle/withhold/query"

# 一键绑卡
V2_QUICKBUCKLE_ONEKEY_CARDBIND = "/v2/quickbuckle/onekey/cardbind"

# DM取现额度查询
V2_TRADE_SETTLEMENT_ENCHASHMENT_DMAMT_QUERY = "/v2/trade/settlement/enchashment/dmamt/query"

# 子账户开通配置(2022)
V2_MERCHANT_SETTLE_CONFIG = "/v2/merchant/settle/config"

# 修改子账户配置(2022)
V2_MERCHANT_SETTLE_MODIFY = "/v2/merchant/settle/modify"

# 支付宝直连-申请当面付代签约
V2_MERCHANT_DIRECT_ALIPAY_FACETOFACESIGN_APPLY = "/v2/merchant/direct/alipay/facetofacesign/apply"

# 支付宝直连-换取应用授权令牌
V2_MERCHANT_DIRECT_ALIPAY_APPAUTHTOKEN_EXCHANGE = "/v2/merchant/direct/alipay/appauthtoken/exchange"

# 支付宝直连-查询申请状态
V2_MERCHANT_DIRECT_ALIPAY_APPLYORDERSTATUS_QUERY = "/v2/merchant/direct/alipay/applyorderstatus/query"

# 直付通商户入驻
V2_MERCHANT_DIRECT_ZFT_REG = "/v2/merchant/direct/zft/reg"

# 直付通分账关系查询
V2_MERCHANT_DIRECT_ZFT_RECEIVER_QUERY = "/v2/merchant/direct/zft/receiver/query"

# 直付通分账关系绑定解绑
V2_MERCHANT_DIRECT_ZFT_RECEIVER_CONFIG = "/v2/merchant/direct/zft/receiver/config"

# 服务商终端列表查询
V2_TERMINALDEVICE_MANAGE_QUERY = "/v2/terminaldevice/manage/query"

# 终端解绑
V2_TERMINALDEVICE_MANAGE_UNBIND = "/v2/terminaldevice/manage/unbind"

# 终端绑定
V2_TERMINALDEVICE_MANAGE_BIND = "/v2/terminaldevice/manage/bind"

# 注销终端
V2_TERMINALDEVICE_DEVICEINFO_CANCEL = "/v2/terminaldevice/deviceInfo/cancel"

# 新增终端报备
V2_TERMINALDEVICE_DEVICEINFO_ADD = "/v2/terminaldevice/deviceInfo/add"

# 绑定终端信息查询
V2_TERMINALDEVICE_DEVICEINFO_QUERY = "/v2/terminaldevice/deviceInfo/query"

# 微信支付宝预授权完成撤销
V2_TRADE_PAYMENT_PREAUTHPAYCANCEL_REFUND = "/v2/trade/payment/preauthpaycancel/refund"

# 微信支付宝预授权完成
V2_TRADE_PREAUTHPAY = "/v2/trade/preauthpay"

# 微信支付宝预授权撤销
V2_TRADE_PAYMENT_PREAUTHCANCEL_REFUND = "/v2/trade/payment/preauthcancel/refund"

# 微信支付宝预授权
V2_TRADE_PREAUTH = "/v2/trade/preauth"

# 银联活动商户信息查询
V2_MERCHANT_ACTIVITY_UNIONPAY_MERBASEINFO_QUERY = "/v2/merchant/activity/unionpay/merbaseInfo/query"

# 银联活动商户入驻状态查询
V2_MERCHANT_ACTIVITY_UNIONPAY_REGISTE_STATUS_QUERY = "/v2/merchant/activity/unionpay/registe/status/query"

# 银联活动商户入驻
V2_MERCHANT_ACTIVITY_UNIONPAY_MERBASEINFO_APPLY = "/v2/merchant/activity/unionpay/merbaseInfo/apply"

# 银联活动列表查询
V2_MERCHANT_ACTIVITY_UNIONPAY_QUERY = "/v2/merchant/activity/unionpay/query"

# 银联活动报名进度查询
V2_MERCHANT_ACTIVITY_UNIONPAY_SIGN_STATUS = "/v2/merchant/activity/unionpay/sign/status"

# 银联活动报名
V2_MERCHANT_ACTIVITY_UNIONPAY_SIGN = "/v2/merchant/activity/unionpay/sign"

# 用户业务入驻修改
V2_USER_BUSI_MODIFY = "/v2/user/busi/modify"

# 用户业务入驻
V2_USER_BUSI_OPEN = "/v2/user/busi/open"

# 用户信息查询
V2_USER_BASICDATA_QUERY = "/v2/user/basicdata/query"

# 企业用户基本信息开户
V2_USER_BASICDATA_ENT = "/v2/user/basicdata/ent"

# 企业用户基本信息修改
V2_USER_BASICDATA_ENT_MODIFY = "/v2/user/basicdata/ent/modify"

# 个人用户基本信息开户
V2_USER_BASICDATA_INDV = "/v2/user/basicdata/indv"

# 个人用户基本信息修改
V2_USER_BASICDATA_INDV_MODIFY = "/v2/user/basicdata/indv/modify"

# 线上交易退款查询
V2_TRADE_ONLINEPAYMENT_REFUND_QUERY = "/v2/trade/onlinepayment/refund/query"

# 线上交易退款
V2_TRADE_ONLINEPAYMENT_REFUND = "/v2/trade/onlinepayment/refund"

# 线上交易查询
V2_TRADE_ONLINEPAYMENT_QUERY = "/v2/trade/onlinepayment/query"

# 网银支付
V2_TRADE_ONLINEPAYMENT_BANKING_FRONTPAY = "/v2/trade/onlinepayment/banking/frontpay"

# 网银支持银行列表查询
V2_TRADE_ONLINEPAYMENT_BANKPAY_BANKLIST = "/v2/trade/onlinepayment/bankpay/banklist"

# 手机WAP支付
V2_TRADE_ONLINEPAYMENT_WAPPAY = "/v2/trade/onlinepayment/wappay"

# 网银付款银行账户查询
V2_TRADE_ONLINEPAYMENT_BANKPAY_PAYERQUERY = "/v2/trade/onlinepayment/bankpay/payerquery"

# 证书登记
V2_MERCHANT_DIRECT_CERTINFO_ADD = "/v2/merchant/direct/certinfo/add"

# 微信直连-修改微信结算帐号
V2_MERCHANT_DIRECT_WECHAT_SETTLEMENTINFO_MODIFY = "/v2/merchant/direct/wechat/settlementInfo/modify"

# 微信特约商户进件
V2_MERCHANT_DIRECT_WECHAT_SIGN = "/v2/merchant/direct/wechat/sign"

# 微信直连-微信关注配置查询
V2_MERCHANT_DIRECT_WECHAT_SUBSCRIBE_QUERY = "/v2/merchant/direct/wechat/subscribe/query"

# 微信直连-微信关注配置
V2_MERCHANT_DIRECT_WECHAT_SUBSCRIBE_CONFIG = "/v2/merchant/direct/wechat/subscribe/config"

# 查询微信申请状态
V2_MERCHANT_DIRECT_WECHAT_QUERY = "/v2/merchant/direct/wechat/query"

# 微信直连-查询微信结算账户
V2_MERCHANT_DIRECT_WECHAT_SETTLEMENTINFO_QUERY = "/v2/merchant/direct/wechat/settlementInfo/query"

# 微信用户标识查询接口
V2_TRADE_WXUSERMARK_QUERY = "/v2/trade/wxusermark/query"

# 银联统一在线收银台
V2_TRADE_ONLINEPAYMENT_UNIONPAY = "/v2/trade/onlinepayment/unionpay"

# 手续费试算
V2_TRADE_FEECALC = "/v2/trade/feecalc"

# 支付宝实名申请提交
V2_MERCHANT_BUSI_ALI_REALNAME_APPLY = "/v2/merchant/busi/ali/realname/apply"

# 支付宝实名申请单查询
V2_MERCHANT_BUSI_ALI_REALNAME_QUERY = "/v2/merchant/busi/ali/realname/query"

# 微信实名认证状态查询
V2_MERCHANT_BUSI_REALNAME_QUERY = "/v2/merchant/busi/realname/query"

# 微信实名认证
V2_MERCHANT_BUSI_REALNAME = "/v2/merchant/busi/realname"

# 微信配置查询
V2_MERCHANT_BUSI_CONFIG_QUERY = "/v2/merchant/busi/config/query"

# 微信商户配置
V2_MERCHANT_BUSI_CONFIG = "/v2/merchant/busi/config"

# 申请单状态查询
V2_MERCHANT_BASICDATA_STATUS_QUERY = "/v2/merchant/basicdata/status/query"

# 商户业务开通修改(2022)
V2_MERCHANT_BUSI_MODIFY = "/v2/merchant/busi/modify"

# 商户业务开通(2022)
V2_MERCHANT_BUSI_OPEN = "/v2/merchant/busi/open"

# 商户详细信息查询(2022)
V2_MERCHANT_BASICDATA_QUERY = "/v2/merchant/basicdata/query"

# 商户统一进件（页面版）
V2_MERCHANT_URL_FORWARD = "/v2/merchant/url/forward"

# 商户统一进件接口(2022)
V2_MERCHANT_INTEGRATE_REG = "/v2/merchant/integrate/reg"

# 商户统一变更接口(2022)
V2_MERCHANT_INTEGRATE_UPDATE = "/v2/merchant/integrate/update"

# 图片上传
V2_SUPPLEMENTARY_PICTURE = "/v2/supplementary/picture"

# 商户基本信息修改(2022)
V2_MERCHANT_BASICDATA_MODIFY = "/v2/merchant/basicdata/modify"

# 商户活动报名查询
V2_MERCHANT_ACTIVITY_QUERY = "/v2/merchant/activity/query"

# 商户活动报名
V2_MERCHANT_ACTIVITY_ADD = "/v2/merchant/activity/add"

# 个人商户基本信息入驻(2022)
V2_MERCHANT_BASICDATA_INDV = "/v2/merchant/basicdata/indv"

# 商户微信支付宝ID查询
V2_MERCHANT_BUSI_MERCODE_QUERY = "/v2/merchant/busi/mercode/query"

# 微信支付宝入驻信息修改
V2_MERCHANT_BUSI_AT_MODIFY = "/v2/merchant/busi/at/modify"

# 支付宝申诉提交凭证
V2_MERCHANT_COMPLAINT_SUBMIT_CERTIFICATES = "/v2/merchant/complaint/submit/certificates"

# 支付宝申诉查询
V2_MERCHANT_COMPLAINT_QUERY_STATUS = "/v2/merchant/complaint/query/status"

# 支付宝申诉请求凭证
V2_MERCHANT_COMPLAINT_REQUEST_CERTIFICATES = "/v2/merchant/complaint/request/certificates"

# 支付宝投诉查询
V2_MERCHANT_COMPLAINT_ALI_RISKINFO_QUERY = "/v2/merchant/complaint/ali/riskinfo/query"

# 查询投诉协商历史
V2_MERCHANT_COMPLAINT_HISTORY_QUERY = "/v2/merchant/complaint/history/query"

# 查询投诉单列表及详情
V2_MERCHANT_COMPLAINT_LIST_INFO_QUERY = "/v2/merchant/complaint/list/info/query"

# 投诉图片下载
V2_MERCHANT_COMPLAINT_DOWNLOAD_PICTURE = "/v2/merchant/complaint/download/picture"

# 更新退款审批结果
V2_MERCHANT_COMPLAINT_UPDATE_REFUNDPROGRESS = "/v2/merchant/complaint/update/refundprogress"

# 回复用户
V2_MERCHANT_COMPLAINT_REPLY = "/v2/merchant/complaint/reply"

# 反馈处理完成
V2_MERCHANT_COMPLAINT_COMPLETE = "/v2/merchant/complaint/complete"

# 商户状态变更
V2_MERCHANT_BUSI_MODIFY_BUSISTATUS = "/v2/merchant/busi/modify/busistatus"

# 取现
V2_TRADE_SETTLEMENT_ENCHASHMENT = "/v2/trade/settlement/enchashment"

# 获取银联用户标识接口
V2_TRADE_PAYMENT_USERMARK2_QUERY = "/v2/trade/payment/usermark2/query"

# 交易退款查询接口
V2_TRADE_PAYMENT_SCANPAY_REFUNDQUERY = "/v2/trade/payment/scanpay/refundquery"

# 扫码交易退款
V2_TRADE_PAYMENT_SCANPAY_REFUND = "/v2/trade/payment/scanpay/refund"

# 交易关单接口
V2_TRADE_PAYMENT_SCANPAY_CLOSE = "/v2/trade/payment/scanpay/close"

# 交易查询接口
V2_TRADE_PAYMENT_SCANPAY_QUERY = "/v2/trade/payment/scanpay/query"

# 批量交易状态查询
V2_TRADE_TRANSSTAT_QUERY = "/v2/trade/transstat/query"

# 快捷支付申请
V2_TRADE_ONLINEPAYMENT_QUICKPAY_APPLY = "/v2/trade/onlinepayment/quickpay/apply"

# 快捷支付确认
V2_TRADE_ONLINEPAYMENT_QUICKPAY_CONFIRM = "/v2/trade/onlinepayment/quickpay/confirm"

# 快捷支付页面版接口
V2_TRADE_ONLINEPAYMENT_QUICKPAY_PAGEINFO = "/v2/trade/onlinepayment/quickpay/pageinfo"

# 新增快捷/代扣解绑接口
V2_QUICKBUCKLE_UNBIND = "/v2/quickbuckle/unbind"

# 快捷绑卡申请接口
V2_QUICKBUCKLE_APPLY = "/v2/quickbuckle/apply"

# 快捷绑卡确认接口
V2_QUICKBUCKLE_CONFIRM = "/v2/quickbuckle/confirm"

# 交易确认退款接口
V2_TRADE_PAYMENT_DELAYTRANS_CONFIRMREFUND = "/v2/trade/payment/delaytrans/confirmrefund"

# 交易确认查询接口
V2_TRADE_PAYMENT_DELAYTRANS_CONFIRMQUERY = "/v2/trade/payment/delaytrans/confirmquery"

# 交易确认接口
V2_TRADE_PAYMENT_DELAYTRANS_CONFIRM = "/v2/trade/payment/delaytrans/confirm"

# 账户余额信息查询接口
V2_TRADE_ACCTPAYMENT_BALANCE_QUERY = "/v2/trade/acctpayment/balance/query"

# 交易结算对账单配置查询
V2_MERCHANT_BUSI_BILL_QUERY = "/v2/merchant/busi/bill/query"

# 交易结算对账文件配置
V2_MERCHANT_BUSI_BILL_CONFIG = "/v2/merchant/busi/bill/config"

# 交易结算对账单查询
V2_TRADE_CHECK_FILEQUERY = "/v2/trade/check/filequery"

# 交易结算对账文件重新生成
V2_TRADE_CHECK_REPLAY = "/v2/trade/check/replay"

# 交易关单查询接口
V2_TRADE_PAYMENT_SCANPAY_CLOSEQUERY = "/v2/trade/payment/scanpay/closequery"

# 结算记录查询
V2_MERCHANT_BASICDATA_SETTLEMENT_QUERY = "/v2/merchant/basicdata/settlement/query"

# 聚合正扫接口
V2_TRADE_PAYMENT_JSPAY = "/v2/trade/payment/jspay"

# 聚合反扫接口
V2_TRADE_PAYMENT_MICROPAY = "/v2/trade/payment/micropay"

# 商户分期配置详情查询
V2_PCREDIT_FEE_DETAIL = "/v2/pcredit/fee/detail"

# 商户分期配置
V2_PCREDIT_FEE_CONFIG = "/v2/pcredit/fee/config"

# 银行卡分期支持银行查询
V2_TRADE_BANKINSTALLMENTINFO_QUERY = "/v2/trade/bankinstallmentinfo/query"

# 分期证书配置
V2_PCREDIT_CERTIFICATE_CONFIG = "/v2/pcredit/certificate/config"

# 花呗分期活动查询
V2_PCREDIT_SOLUTION_QUERY = "/v2/pcredit/solution/query"

# 更新花呗分期方案
V2_PCREDIT_SOLUTION_MODIFY = "/v2/pcredit/solution/modify"

# 上架下架分期活动接口
V2_PCREDIT_STATUE_MODIFY = "/v2/pcredit/statue/modify"

# 花呗分期贴息查询
V2_PCREDIT_ORDER_QUERY = "/v2/pcredit/order/query"

# 创建花呗分期方案
V2_PCREDIT_SOLUTION_CREATE = "/v2/pcredit/solution/create"

# 商户分账配置查询(2022)
V2_MERCHANT_SPLIT_QUERY = "/v2/merchant/split/query"

# 商户分账配置(2022)
V2_MERCHANT_SPLIT_CONFIG = "/v2/merchant/split/config"

# 交易分账明细查询
V2_TRADE_TRANS_SPLIT_QUERY = "/v2/trade/trans/split/query"

# 电子回单查询
V2_TRADE_PAYMENT_GETELECTRONICRECEIPT = "/v2/trade/payment/getelectronicreceipt"

# 银行大额资金流水查询
V2_TRADE_ONLINEPAYMENT_TRANSFER_ACCOUNT_QUERY = "/v2/trade/onlinepayment/transfer/account/query"

# 银行大额支付关单
V2_TRADE_ONLINEPAYMENT_TRANSFER_ACCOUNT_CLOSE = "/v2/trade/onlinepayment/transfer/account/close"

# 银行大额支付
V2_TRADE_ONLINEPAYMENT_TRANSFER_ACCOUNT = "/v2/trade/onlinepayment/transfer/account"

# 银行卡代发
V2_TRADE_SETTLEMENT_SURROGATE = "/v2/trade/settlement/surrogate"

# 微信代发查询
V2_TRADE_TRANS_WXSURROGATE_QUERY = "/v2/trade/trans/wxsurrogate/query"

# 微信代发
V2_TRADE_TRANS_WX_SURROGATE = "/v2/trade/trans/wx/surrogate"

# 支付宝小程序预下单接口
V2_TRADE_HOSTING_PAYMENT_PREORDER = "/v2/trade/hosting/payment/preorder"

# 出金交易查询接口
V2_TRADE_SETTLEMENT_QUERY = "/v2/trade/settlement/query"

# 卡bin信息查询
V2_TRADE_CARDBIN_QUERY = "/v2/trade/cardbin/query"

# 余额支付
V2_TRADE_ACCTPAYMENT_PAY = "/v2/trade/acctpayment/pay"

# 余额支付退款查询
V2_TRADE_ACCTPAYMENT_REFUND_QUERY = "/v2/trade/acctpayment/refund/query"

# 余额支付退款
V2_TRADE_ACCTPAYMENT_REFUND = "/v2/trade/acctpayment/refund"

# 余额支付查询
V2_TRADE_ACCTPAYMENT_PAY_QUERY = "/v2/trade/acctpayment/pay/query"

# 账务流水查询
V2_TRADE_ACCTPAYMENT_ACCTLOG_QUERY = "/v2/trade/acctpayment/acctlog/query"

# 企业商户基本信息入驻(2022)
V2_MERCHANT_BASICDATA_ENT = "/v2/merchant/basicdata/ent"



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_MERCHANT_COMPLAINT_COMPLETE



class V2MerchantComplaintCompleteRequest(object):
    """
    反馈处理完成
    """

    # 请求流水号
    req_seq_id = ""
    # 请求时间
    req_date = ""
    # 微信投诉单号
    complaint_id = ""
    # 被诉商户微信号
    complainted_mchid = ""
    # 微信商户号
    mch_id = ""

    def post(self, extend_infos):
        """
        反馈处理完成

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "complaint_id":self.complaint_id,
            "complainted_mchid":self.complainted_mchid,
            "mch_id":self.mch_id
        }
        required_params.update(extend_infos)
        return request_post(V2_MERCHANT_COMPLAINT_COMPLETE, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_ONLINEPAYMENT_TRANSFER_BANKMISTAKE_APPLY



class V2TradeOnlinepaymentTransferBankmistakeApplyRequest(object):
    """
    银行大额支付差错申请
    """

    # 请求流水号
    req_seq_id = ""
    # 请求日期
    req_date = ""
    # 商户号
    huifu_id = ""
    # 交易金额
    trans_amt = ""
    # 订单类型
    order_type = ""
    # 原请求流水号
    org_req_seq_id = ""
    # 原请求日期
    org_req_date = ""
    # 异步通知地址
    notify_url = ""
    # 商品描述
    goods_desc = ""
    # 汇款凭证文件id
    certificate_file_id = ""

    def post(self, extend_infos):
        """
        银行大额支付差错申请

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_seq_id":self.req_seq_id,
            "req_date":self.req_date,
            "huifu_id":self.huifu_id,
            "trans_amt":self.trans_amt,
            "order_type":self.order_type,
            "org_req_seq_id":self.org_req_seq_id,
            "org_req_date":self.org_req_date,
            "notify_url":self.notify_url,
            "goods_desc":self.goods_desc,
            "certificate_file_id":self.certificate_file_id
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_ONLINEPAYMENT_TRANSFER_BANKMISTAKE_APPLY, required_params)



from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_SUPPLEMENTARY_PICTURE
import os


class V2SupplementaryPictureRequest(object):
    """
    图片上传
    """

    # 业务请求流水号
    req_seq_id = ""
    # 业务请求日期
    req_date = ""
    # 图片类型
    file_type = ""

    def post(self, extend_infos):
        """
        图片上传

        :param extend_infos: 扩展字段字典
        :return:
        """

        file = {'picture': (
            os.path.basename(self.picture), open(self.picture, 'rb'), 'application/octet-stream')}

        required_params = {
            "file_type": self.file_type,
            "picture": os.path.basename(self.picture)
        }
        return request_post(V2_SUPPLEMENTARY_PICTURE, required_params, file, need_sign=False, need_verfy_sign=False)
